<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
	<xsl:output method="xml"/>
	<xsl:template name="ErrorNode">
		<xsl:param name="MessErr"/>
		<xsl:param name="DocId"/>
		<xsl:param name="PathErr"/>
		<xsl:param name="Category"/>
		<xsl:param name="Num"/>
		<xsl:param name="TypeDoc"/>
		<xsl:param name="PosPkg"/>
		<xsl:variable name="Cat">
			<xsl:choose>
				<xsl:when test="string-length($Category)=0">ERROR</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$Category"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<RESULTINFORMATION_ITEM xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<ResultDescription>
				<xsl:value-of select="$MessErr"/>
			</ResultDescription>
			<ResultIdDocument>
				<xsl:value-of select="$DocId"/>
			</ResultIdDocument>
			<ResultTypeDocument>
				<xsl:value-of select="$TypeDoc"/>
			</ResultTypeDocument>
			<ResultPosInPkgDocument>
				<xsl:value-of select="$PosPkg"/>
			</ResultPosInPkgDocument>
			<ResultPathNode>
				<xsl:value-of select="$PathErr"/>
			</ResultPathNode>
			<ResultCategory>
				<xsl:value-of select="$Cat"/>
			</ResultCategory>
			<DocumentNumber>
				<xsl:value-of select="$Num"/>
			</DocumentNumber>
		</RESULTINFORMATION_ITEM>
	</xsl:template>
	<xsl:template match="/">
		<xsl:apply-templates select="//Package"/>
	</xsl:template>
	<xsl:template match="Package">
		<ResultInformation xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<xsl:for-each select="//REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM">
				<xsl:variable name="IdRap" select="../@id"/>
				<xsl:variable name="RapPos" select="position()"/>
				<xsl:variable name="RapType" select="../@ctmtd:CfgName"/>
				<xsl:if test="string-length(Representative_LicenseNumber)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров с не заполненным полем Таможенный представитель:Номер лицензии.'"/>
						<xsl:with-param name="DocId" select="$IdRap"/>
						<xsl:with-param name="PathErr" select="'REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/Representative_LicenseNumber'"/>
						<xsl:with-param name="TypeDoc" select="$RapType"/>
						<xsl:with-param name="PosPkg" select="$RapPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Representative_OrganizationLanguage)>0 and string-length(Representative_OrganizationLanguage)!=2">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров с неправильно заполненным полем Таможенный представитель:Код языка для заполнения наименования.'"/>
						<xsl:with-param name="DocId" select="$IdRap"/>
						<xsl:with-param name="PathErr" select="'REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/Representative_OrganizationLanguage'"/>
						<xsl:with-param name="TypeDoc" select="$RapType"/>
						<xsl:with-param name="PosPkg" select="$RapPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(ApplicationSign)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров с не заполненным полем Тип реестра.'"/>
						<xsl:with-param name="DocId" select="$IdRap"/>
						<xsl:with-param name="PathErr" select="'REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/ApplicationSign'"/>
						<xsl:with-param name="TypeDoc" select="$RapType"/>
						<xsl:with-param name="PosPkg" select="$RapPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(ApplicationReg_CustomsCode)=0 and (string-length(ApplicationReg_Date)>0 or string-length(ApplicationReg_Number)>0)">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров,в котором раздел Регистрационный номер исходного реестра, если товары возвращаемые заполнен не полностью (код ТО).'"/>
						<xsl:with-param name="DocId" select="$IdRap"/>
						<xsl:with-param name="PathErr" select="'REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/ApplicationReg_CustomsCode'"/>
						<xsl:with-param name="TypeDoc" select="$RapType"/>
						<xsl:with-param name="PosPkg" select="$RapPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(ApplicationReg_Date)=0 and (string-length(ApplicationReg_CustomsCode)>0 or string-length(ApplicationReg_Number)>0)">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров,в котором раздел Регистрационный номер исходного реестра, если товары возвращаемые заполнен не полностью (Дата).'"/>
						<xsl:with-param name="DocId" select="$IdRap"/>
						<xsl:with-param name="PathErr" select="'REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/ApplicationReg_Date'"/>
						<xsl:with-param name="TypeDoc" select="$RapType"/>
						<xsl:with-param name="PosPkg" select="$RapPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(ApplicationReg_Number)=0 and (string-length(ApplicationReg_CustomsCode)>0 or string-length(ApplicationReg_Date)>0)">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров,в котором раздел Регистрационный номер исходного реестра, если товары возвращаемые заполнен не полностью (Номер).'"/>
						<xsl:with-param name="DocId" select="$IdRap"/>
						<xsl:with-param name="PathErr" select="'REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/ApplicationReg_Number'"/>
						<xsl:with-param name="TypeDoc" select="$RapType"/>
						<xsl:with-param name="PosPkg" select="$RapPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="string-length(Warehouse_CertificateNumber)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров c не заполненым полем СВХ, на котором размещены товары : Номер лицензии.'"/>
							<xsl:with-param name="DocId" select="$IdRap"/>
							<xsl:with-param name="PathErr" select="'REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/Warehouse_CertificateNumber'"/>
							<xsl:with-param name="TypeDoc" select="$RapType"/>
							<xsl:with-param name="PosPkg" select="$RapPos"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="string-length(substring-before(Warehouse_CertificateNumber, '/'))!=5">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров c неверно заполненным полем номером лицензии СВХ, на котором размещены товары: первая часть номера должна состоять из пяти цифр (код РТУ).'"/>
							<xsl:with-param name="DocId" select="$IdRap"/>
							<xsl:with-param name="PathErr" select="'REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/Warehouse_CertificateNumber'"/>
							<xsl:with-param name="TypeDoc" select="$RapType"/>
							<xsl:with-param name="PosPkg" select="$RapPos"/>
						</xsl:call-template>
					</xsl:when>
				</xsl:choose>
				<xsl:for-each select="CONSIGMENT/CONSIGMENT_ITEM">
					<xsl:if test="string-length(ListNumeric)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров c не заполненым полем в Товарной партии Номер партии товаров по порядку в текущем реестре.'"/>
							<xsl:with-param name="DocId" select="$IdRap"/>
							<xsl:with-param name="PathErr" select="concat('REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/CONSIGMENT/CONSIGMENT_ITEM[',position(),']/ListNumeric')"/>
							<xsl:with-param name="TypeDoc" select="$RapType"/>
							<xsl:with-param name="PosPkg" select="$RapPos"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="string-length(CurrencyCode_Bill)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров c не заполненым полем в Товарной партии Код валюты счета (сделки).'"/>
							<xsl:with-param name="DocId" select="$IdRap"/>
							<xsl:with-param name="PathErr" select="concat('REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/CONSIGMENT/CONSIGMENT_ITEM[',position(),']/CurrencyCode_Bill')"/>
							<xsl:with-param name="TypeDoc" select="$RapType"/>
							<xsl:with-param name="PosPkg" select="$RapPos"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="string-length(CurrencyRate_Bill)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров c не заполненым полем в Товарной партии Курс валюты счета (сделки) к евро.'"/>
							<xsl:with-param name="DocId" select="$IdRap"/>
							<xsl:with-param name="PathErr" select="concat('REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/CONSIGMENT/CONSIGMENT_ITEM[',position(),']/CurrencyRate_Bill')"/>
							<xsl:with-param name="TypeDoc" select="$RapType"/>
							<xsl:with-param name="PosPkg" select="$RapPos"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="string-length(Consignor_Name)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров c не заполненым полем в Товарной партии Отправитель: наименование.'"/>
							<xsl:with-param name="DocId" select="$IdRap"/>
							<xsl:with-param name="PathErr" select="concat('REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/CONSIGMENT/CONSIGMENT_ITEM[',position(),']/Consignor_Name')"/>
							<xsl:with-param name="TypeDoc" select="$RapType"/>
							<xsl:with-param name="PosPkg" select="$RapPos"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="string-length(Consignee_Name)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров c не заполненым полем в Товарной партии Получатель: наименование.'"/>
							<xsl:with-param name="DocId" select="$IdRap"/>
							<xsl:with-param name="PathErr" select="concat('REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/CONSIGMENT/CONSIGMENT_ITEM[',position(),']/Consignee_Name')"/>
							<xsl:with-param name="TypeDoc" select="$RapType"/>
							<xsl:with-param name="PosPkg" select="$RapPos"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="string-length(Consignee_ConsigneeSign)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров c не заполненым полем в Товарной партии Признак получателя.'"/>
							<xsl:with-param name="DocId" select="$IdRap"/>
							<xsl:with-param name="PathErr" select="concat('REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/CONSIGMENT/CONSIGMENT_ITEM[',position(),']/Consignee_ConsigneeSign')"/>
							<xsl:with-param name="TypeDoc" select="$RapType"/>
							<xsl:with-param name="PosPkg" select="$RapPos"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:variable name="PosCons" select="position()"/>
					<xsl:for-each select="WAYBILL/WAYBILL_ITEM">
						<xsl:if test="string-length(WayBillKind)=0">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров c не заполненым полем в Товарной партии разделе Сведения об общих накладных Тип накладной.'"/>
								<xsl:with-param name="DocId" select="$IdRap"/>
								<xsl:with-param name="PathErr" select="concat('REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/CONSIGMENT/CONSIGMENT_ITEM[',$PosCons,']/WAYBILL/WAYBILL_ITEM[',position(),']/WayBillKind')"/>
								<xsl:with-param name="TypeDoc" select="$RapType"/>
								<xsl:with-param name="PosPkg" select="$RapPos"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:for-each>
					<xsl:for-each select="GOODS/GOODS_ITEM">
						<xsl:variable name="PosConsGood" select="position()"/>
						<xsl:if test="string-length(GoodsDescription)=0">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров c не заполненым полем в Товарной партии разделе Товары Наименование.'"/>
								<xsl:with-param name="DocId" select="$IdRap"/>
								<xsl:with-param name="PathErr" select="concat('REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/CONSIGMENT/CONSIGMENT_ITEM[',$PosCons,']/GOODS/GOODS_ITEM[',position(),']/GoodsDescription')"/>
								<xsl:with-param name="TypeDoc" select="$RapType"/>
								<xsl:with-param name="PosPkg" select="$RapPos"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="string-length(GrossWeightQuantity)=0">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров c не заполненым полем в Товарной партии разделе Товары Вес брутто.'"/>
								<xsl:with-param name="DocId" select="$IdRap"/>
								<xsl:with-param name="PathErr" select="concat('REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/CONSIGMENT/CONSIGMENT_ITEM[',$PosCons,']/GOODS/GOODS_ITEM[',position(),']/GrossWeightQuantity')"/>
								<xsl:with-param name="TypeDoc" select="$RapType"/>
								<xsl:with-param name="PosPkg" select="$RapPos"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="string-length(GoodsCost)=0">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров c не заполненым полем в Товарной партии разделе Товары Стоимость товара в валюте счета (сделки).'"/>
								<xsl:with-param name="DocId" select="$IdRap"/>
								<xsl:with-param name="PathErr" select="concat('REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/CONSIGMENT/CONSIGMENT_ITEM[',$PosCons,']/GOODS/GOODS_ITEM[',position(),']/GoodsCost')"/>
								<xsl:with-param name="TypeDoc" select="$RapType"/>
								<xsl:with-param name="PosPkg" select="$RapPos"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="string-length(GoodsCostEuro)=0">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров c не заполненым полем в Товарной партии разделе Товары Стоимость товара в евро.'"/>
								<xsl:with-param name="DocId" select="$IdRap"/>
								<xsl:with-param name="PathErr" select="concat('REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/CONSIGMENT/CONSIGMENT_ITEM[',$PosCons,']/GOODS/GOODS_ITEM[',position(),']/GoodsCostEuro')"/>
								<xsl:with-param name="TypeDoc" select="$RapType"/>
								<xsl:with-param name="PosPkg" select="$RapPos"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:for-each select="GOODSQUANTITY/GOODSQUANTITY_ITEM">
							<xsl:if test="string-length(Quantity)=0">
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ Реестр доставляемых/возвращаемых товаров c не заполненым полем в Товарной партии разделе Товары Количество товара.'"/>
									<xsl:with-param name="DocId" select="$IdRap"/>
									<xsl:with-param name="PathErr" select="concat('REPRESENTATIVEAPPLICATION/REPRESENTATIVEAPPLICATION_ITEM/CONSIGMENT/CONSIGMENT_ITEM[',$PosCons,']/GOODS/GOODS_ITEM[',$PosConsGood,']/GOODSQUANTITY/GOODSQUANTITY_ITEM[',position(),']/Quantity')"/>
									<xsl:with-param name="TypeDoc" select="$RapType"/>
									<xsl:with-param name="PosPkg" select="$RapPos"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:for-each>
					</xsl:for-each>
				</xsl:for-each>
			</xsl:for-each>
		</ResultInformation>
	</xsl:template>
</xsl:stylesheet>
