<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
	<xsl:template name="ErrorNode">
		<xsl:param name="MessErr"/>
		<xsl:param name="DocId"/>
		<xsl:param name="PathErr"/>
		<xsl:param name="TypeDoc"/>
		<xsl:param name="PosPkg"/>
		<RESULTINFORMATION_ITEM>
			<ResultDescription><xsl:value-of select="$MessErr"/></ResultDescription>
			<ResultIdDocument><xsl:value-of select="$DocId"/></ResultIdDocument>
			<ResultTypeDocument><xsl:value-of select="$TypeDoc"/></ResultTypeDocument>
			<ResultPosInPkgDocument><xsl:value-of select="$PosPkg"/></ResultPosInPkgDocument>
			<ResultPathNode><xsl:value-of select="$PathErr"/></ResultPathNode>
		</RESULTINFORMATION_ITEM>	
	</xsl:template>
	<xsl:template name="ValidContainerNum">
		<xsl:param name="Nums"/>
		<xsl:param name="notSea"/>
		<xsl:variable name="Sing0" select="string-length($Nums)&lt;18"/>
		<xsl:variable name="Sing1" select="substring($Nums,1,4)"/>
		<xsl:variable name="Sing2" select="substring($Nums,5)"/>
		<xsl:variable name="Sing11" select="translate($Sing1,'QWERTYUIOPASDFGHJKLMNBVCXZ','AAAAAAAAAAAAAAAAAAAAAAAAAA')"/>
		<xsl:variable name="Sing21">
			<xsl:choose>
				<xsl:when test="number($Sing2)!='NaN'">
					<xsl:value-of select="translate($Sing2,'0123456789', '9999999999')"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$Sing2"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="$Sing0 and $Sing11='AAAA' and $Sing21='9999999'">1</xsl:when>
			<xsl:otherwise>0</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- проверка связанности док-тов в пакете-->
	<xsl:key name="ConocamentUINPIT" use="concat(./ConosamentNum,./UIN_ID)" match="//NUMUIN_ITEM"/>
	<xsl:template name="FlkSea">
		<xsl:param name="ConosamentFromArrSeaDcl"/>
		<xsl:param name="AllFlk"/>
		<xsl:variable name="SeaBalast" select="string-length(//GENERALDECL_ITEM/Balast)>0 and number(//GENERALDECL_ITEM/Balast)=1"/>
		<xsl:variable name="NotInvSea" select="count(//WHDOCINVENTORY_ITEM)=0  and count(//OEZ_IMPORTEXPORTNOTIF_ITEM)=0 and count(//OEZ_INVENTORY)=0 and count(//EDTRANSIT_INVENTORY_ITEM)=0 and count(//PMP_INVENTORY_ITEM)=0"/>
		<xsl:if test="$NotInvSea">
			<xsl:if test="count(//ARRSEADECL/ARRSEADECL_ITEM)>0 and count(//CONOSAMENT/CONOSAMENT_ITEM)=0 and count(//ARRSEADECLGoods/ARRSEADECLGOODS_ITEM)=0"> 
				<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'Пакет не содержит сведений о товарных партиях.'"/>
					<xsl:with-param name="DocId" select="//ARRSEADECL/@id"/>
					<xsl:with-param name="PathErr" select="'ARRSEADECL/ARRSEADECL_ITEM/RegNum'"/>		
					<xsl:with-param name="Num" select="//ARRSEADECL/ARRSEADECL_ITEM/RegNum"/>				
				</xsl:call-template>						
			</xsl:if>
			<xsl:for-each select="//ARRSEADECL/ARRSEADECL_ITEM">
				<xsl:variable name="DepPort">
					<xsl:choose>
						<xsl:when test="string-length(DeparturePort)>0">
							<xsl:value-of select="DeparturePort"/>
						</xsl:when>
						<xsl:when test="//GENERALDECL/GENERALDECL_ITEM/ArrivalIndicator=1 and  string-length(//GENERALDECL/GENERALDECL_ITEM/DeparturePort)>0">
							<xsl:value-of select="//GENERALDECL/GENERALDECL_ITEM/DeparturePort"/>
						</xsl:when>
						<xsl:when test="//GENERALDECL/GENERALDECL_ITEM/ArrivalIndicator=0 and  string-length(//GENERALDECL/GENERALDECL_ITEM/DestinationPort)>0">
							<xsl:value-of select="//GENERALDECL/GENERALDECL_ITEM/DestinationPort"/>
						</xsl:when>	
					</xsl:choose>	
				</xsl:variable>	
				<xsl:if test="string-length($DepPort)=0">	
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с не заполненным полем Название порта отправления судна.'"/>
						<xsl:with-param name="DocId" select="../@id"/>
						<xsl:with-param name="PathErr" select="'ARRSEADECL[1]/ARRSEADECL_ITEM/DeparturePort'"/>
						<xsl:with-param name="TypeDoc" select="../@ctmtd:CfgName"/>
						<xsl:with-param name="PosPkg" select="position()"/>						
					</xsl:call-template>						
				</xsl:if>
				<xsl:variable name="DeclPort">
					<xsl:choose>
						<xsl:when test="string-length(DeclarationPort)>0">
							<xsl:value-of select="DeclarationPort"/>
						</xsl:when>
						<xsl:when test="//GENERALDECL/GENERALDECL_ITEM/ArrivalIndicator=0 and  string-length(//GENERALDECL/GENERALDECL_ITEM/DeparturePort)>0">
							<xsl:value-of select="//GENERALDECL/GENERALDECL_ITEM/DeparturePort"/>
						</xsl:when>
						<xsl:when test="//GENERALDECL/GENERALDECL_ITEM/ArrivalIndicator=1 and  string-length(//GENERALDECL/GENERALDECL_ITEM/DestinationPort)>0">
							<xsl:value-of select="//GENERALDECL/GENERALDECL_ITEM/DestinationPort"/>
						</xsl:when>	
					</xsl:choose>	
				</xsl:variable>
				<xsl:if test="string-length($DeclPort)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с не заполненным полем Название порта составления декларации о грузе.'"/>
						<xsl:with-param name="PathErr" select="'ARRSEADECL[1]/ARRSEADECL_ITEM/DeclarationPort'"/>						
						<xsl:with-param name="DocId" select="../@id"/>
						<xsl:with-param name="TypeDoc" select="../@ctmtd:CfgName"/>
						<xsl:with-param name="PosPkg" select="position()"/>								
					</xsl:call-template>						
				</xsl:if> 
			</xsl:for-each>
			<xsl:for-each select="//DEPSEADECL/DEPSEADECL_ITEM">
				<xsl:variable name="DepPort">
					<xsl:choose>
						<xsl:when test="string-length(DeparturePort)>0">
							<xsl:value-of select="DeparturePort"/>
						</xsl:when>
						<xsl:when test="//GENERALDECL/GENERALDECL_ITEM/ArrivalIndicator=0 and  string-length(//GENERALDECL/GENERALDECL_ITEM/DeparturePort)>0">
							<xsl:value-of select="//GENERALDECL/GENERALDECL_ITEM/DeparturePort"/>
						</xsl:when>
						<xsl:when test="//GENERALDECL/GENERALDECL_ITEM/ArrivalIndicator=1 and  string-length(//GENERALDECL/GENERALDECL_ITEM/DestinationPort)>0">
							<xsl:value-of select="//GENERALDECL/GENERALDECL_ITEM/DestinationPort"/>
						</xsl:when>	
					</xsl:choose>	
				</xsl:variable>	
				<xsl:if test="string-length($DepPort)=0">	
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с не заполненным полем Название порта отправления судна.'"/>
						<xsl:with-param name="DocId" select="../@id"/>
						<xsl:with-param name="PathErr" select="'ARRSEADECL[1]/ARRSEADECL_ITEM/DeparturePort'"/>
						<xsl:with-param name="TypeDoc" select="../@ctmtd:CfgName"/>
						<xsl:with-param name="PosPkg" select="position()"/>						
					</xsl:call-template>						
				</xsl:if>
				<xsl:variable name="DeclPort">
					<xsl:choose>
						<xsl:when test="string-length(DeclarationPort)>0">
							<xsl:value-of select="DeclarationPort"/>
						</xsl:when>
						<xsl:when test="//GENERALDECL/GENERALDECL_ITEM/ArrivalIndicator=1 and  string-length(//GENERALDECL/GENERALDECL_ITEM/DeparturePort)>0">
							<xsl:value-of select="//GENERALDECL/GENERALDECL_ITEM/DeparturePort"/>
						</xsl:when>
						<xsl:when test="//GENERALDECL/GENERALDECL_ITEM/ArrivalIndicator=0 and  string-length(//GENERALDECL/GENERALDECL_ITEM/DestinationPort)>0">
							<xsl:value-of select="//GENERALDECL/GENERALDECL_ITEM/DestinationPort"/>
						</xsl:when>	
					</xsl:choose>	
				</xsl:variable>
				<xsl:if test="string-length($DeclPort)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с не заполненным полем Название порта составления декларации о грузе.'"/>
						<xsl:with-param name="PathErr" select="'ARRSEADECL[1]/ARRSEADECL_ITEM/DeclarationPort'"/>						
						<xsl:with-param name="DocId" select="../@id"/>
						<xsl:with-param name="TypeDoc" select="../@ctmtd:CfgName"/>
						<xsl:with-param name="PosPkg" select="position()"/>								
					</xsl:call-template>						
				</xsl:if> 
			</xsl:for-each>
		</xsl:if>
			<xsl:for-each select="//ARRSEADECL/ARRSEADECL_ITEM">
				<xsl:variable name="IdSeaAr" select="../@id"/>
				<xsl:variable name="AdclPos" select="position()"/>
				<xsl:variable name="AdclType" select="../@ctmtd:CfgName"/> 
			
				<xsl:variable name="decl-HowSend">
					<xsl:choose>
						<xsl:when test="count(//GENERALDECL/GENERALDECL_ITEM/HowSend) = 0">0</xsl:when>
						<xsl:when test="string-length(//GENERALDECL/GENERALDECL_ITEM/HowSend) = 0">0</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="//GENERALDECL/GENERALDECL_ITEM/HowSend"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:if test="string-length(LanguageCode)>0"> 
					<xsl:variable name="LgC">
						<xsl:choose>
							<xsl:when test="translate(LanguageCode,'QWERTYUIOPASDFGHJKLMNBVCXZ','AAAAAAAAAAAAAAAAAAAAAAAAAA')!='AA'">0</xsl:when>
							<xsl:otherwise>1</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:if  test="$LgC=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна, у которого  поле Код языка документа заполнен не правильно.'"/>
							<xsl:with-param name="DocId" select="$IdSeaAr"/>
						<xsl:with-param name="PathErr" select="'ARRSEADECL/ARRSEADECL_ITEM/LanguageCode'"/>						
						<xsl:with-param name="TypeDoc" select="$AdclType"/>
						<xsl:with-param name="PosPkg" select="$AdclPos"/>		
						</xsl:call-template>
					</xsl:if>						
				</xsl:if>
				<xsl:if  test="$NotInvSea">
					<xsl:if test="string-length(DocSig_PersonName)=0 and string-length(//GENERALDECL/GENERALDECL_ITEM/DocSig_PersonName)=0">	
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с не заполненным полем Фамилия в разделе Подпись документа... .'"/>
							<xsl:with-param name="DocId" select="$IdSeaAr"/>
							<xsl:with-param name="PathErr" select="'ARRSEADECL/ARRSEADECL_ITEM/DocSig_PersonName'"/>						
						<xsl:with-param name="TypeDoc" select="$AdclType"/>
						<xsl:with-param name="PosPkg" select="$AdclPos"/>						
						</xsl:call-template>						
					</xsl:if>
					<xsl:if test="string-length(DocSig_PersonName2)=0 and string-length(//GENERALDECL/GENERALDECL_ITEM/DocSig_PersonName2)=0"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с не заполненным полем Имя в разделе Подпись документа... .'"/>
							<xsl:with-param name="DocId" select="$IdSeaAr"/>
							<xsl:with-param name="PathErr" select="'ARRSEADECL/ARRSEADECL_ITEM/DocSig_PersonName2'"/>						
						<xsl:with-param name="TypeDoc" select="$AdclType"/>
						<xsl:with-param name="PosPkg" select="$AdclPos"/>						
						</xsl:call-template>						
					</xsl:if>	
				</xsl:if>
				<xsl:if test="string-length(VesselName)=0">	
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с не заполненным полем Наименование судна.'"/>
						<xsl:with-param name="DocId" select="$IdSeaAr"/>
						<xsl:with-param name="PathErr" select="'ARRSEADECL/ARRSEADECL_ITEM/VesselName'"/>						
						<xsl:with-param name="TypeDoc" select="$AdclType"/>
						<xsl:with-param name="PosPkg" select="$AdclPos"/>						
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="$decl-HowSend=1 and  count(ARRSEADECLGoods/ARRSEADECLGOODS_ITEM/ConosamentNum)=1 and count(//CONOSAMENT/CONOSAMENT_ITEM)=0 and string-length(ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[1]/ConosamentNum)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr">Для отправки пакета в ПИ в товаре Декларации о грузе при приходе судна необходимо заполнить Номер коносамента </xsl:with-param>
						<xsl:with-param name="DocId" select="$IdSeaAr"/>
						<xsl:with-param name="PathErr" select="'ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[1]/ConosamentNum'"/>	
						<xsl:with-param name="TypeDoc" select="$AdclType"/>
						<xsl:with-param name="PosPkg" select="$AdclPos"/>						
					</xsl:call-template>
				</xsl:if> 	
				<xsl:for-each select="ARRSEADECLGoods/ARRSEADECLGOODS_ITEM">
					<xsl:variable name="ArrSeaDclGoods" select="position()"/>
					<xsl:variable name="RNum" select="ConosamentNum"/>
					<xsl:variable name="RID" select="normalize-space(ConosamentID)"/>
					<xsl:if test="count(ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[normalize-space(ConosamentID)=$RID and ConosamentNum!=$RNum and string-length(ConosamentID)>0 and string-length($RID)>0])>0 or count(ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[concat(ConosamentID,ConosamentNum)=concat($RID,$RNum) and string-length(ConosamentID)>0 and string-length($RID)>0])>1 and $NotInvSea">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с товаром, в котором несколько коносаментов с одинаковыми Таможенный идентификационный номер (УИН ПИТ).'"/>
							<xsl:with-param name="DocId" select="$IdSeaAr"/>
							<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/ConosamentID')"/>	
							<xsl:with-param name="Num" select="$RNum"/>					
						<xsl:with-param name="TypeDoc" select="$AdclType"/>
						<xsl:with-param name="PosPkg" select="$AdclPos"/>						
						</xsl:call-template>						
					</xsl:if>
					<xsl:variable name="ValidRID">
						<xsl:call-template name="ValidUIN_NUM">
							<xsl:with-param name="UIN">
								<xsl:call-template name="ClearSimUIN_NUM">
									<xsl:with-param name="UIN" select="normalize-space($RID)"/>
								</xsl:call-template>
							</xsl:with-param>	
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="string-length($RID)>0 and $ValidRID=0 and $NotInvSea">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с товаром, в котором Таможенный идентификационный номер (УИН ПИТ) не соответствует установленному формату (по длине). Документ будет отправлен в ФТС без данного номера.'"/>
							<xsl:with-param name="DocId" select="$IdSeaAr"/>
							<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/ConosamentID')"/>	
							<xsl:with-param name="Num" select="$RNum"/>					
							<xsl:with-param name="TypeDoc" select="$AdclType"/>
							<xsl:with-param name="PosPkg" select="$AdclPos"/>	
							<xsl:with-param name="Category" select="'WARNING'"/>						
						</xsl:call-template>						
					</xsl:if>
					<xsl:if test="string-length($RNum)>0 and count(//CONOSAMENT/CONOSAMENT_ITEM[RegNum=$RNum])=0  and $NotInvSea and (string-length($ConosamentFromArrSeaDcl)=0 or (string-length($ConosamentFromArrSeaDcl)>0 and number($ConosamentFromArrSeaDcl)=0))"> 
						<xsl:if  test="$decl-HowSend>1">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr">
									<xsl:text>Пакет содержит Декларацию о грузе при приходе судна с товаром, у которого указан номер коносамента отсутсвующий в пакете. Для отправки пакета удалите товары с этим коносаменом.</xsl:text>
									<br />
									<xsl:text>ИЛИ для формирования коносаментов из Декларации о грузе при приходе судна в ИМО/Генеральной декларации - не указывать Вид отправки или выбрать "Комплект документов"</xsl:text>
								</xsl:with-param>
								<xsl:with-param name="DocId" select="$IdSeaAr"/>
								<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/ConosamentNum')"/>	
								<xsl:with-param name="Num" select="$RNum"/>					
								<xsl:with-param name="TypeDoc" select="$AdclType"/>
								<xsl:with-param name="PosPkg" select="$AdclPos"/>						
							</xsl:call-template>										
						</xsl:if>		
						<xsl:if test="$decl-HowSend&lt;2"> 
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr">
									<xsl:text>Пакет содержит Декларацию о грузе при приходе судна с товаром, у которого указан номер коносамента отсутсвующий в пакете. </xsl:text>
									<br />
									<xsl:choose>
										<xsl:when test="$decl-HowSend=0">
											<xsl:text>При отправке пакета в контейнер с документами из товаров Декларации о грузе при приходе судна с этим номером коносамета будет сформирован отдельный документ.</xsl:text>
											<br />
											<xsl:text>Для отправки пакета без формирования отсутсвующего коносамета, удалите товары с этим коносаменом из Декларации...</xsl:text>
										</xsl:when>
										<xsl:when test="$decl-HowSend=1">
											<xsl:text>При отправке пакета в ПИ из товаров Декларации о грузе при приходе судна с этим номером коносамета будет сформирована отдельная товарная партия.</xsl:text>
											<br />
											<xsl:text>Для отправки пакета без формирования в ПИ товарной партии по данному коносамету, удалите товары с этим коносаменом из Декларации...</xsl:text>
										</xsl:when>
									</xsl:choose>
								</xsl:with-param>
								<xsl:with-param name="DocId" select="$IdSeaAr"/>
								<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/ConosamentNum')"/>	
								<xsl:with-param name="Num" select="$RNum"/>					
								<xsl:with-param name="TypeDoc" select="$AdclType"/>
								<xsl:with-param name="PosPkg" select="$AdclPos"/>						
								<xsl:with-param name="Category" select="'WARNING'"/>	
							</xsl:call-template>										
						</xsl:if>	
					</xsl:if>
					<xsl:if test="$decl-HowSend=1 and  string-length(DebarkationPortCountryCode)=0"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr">Для отправки пакета в ПИ в товаре Декларации о грузе при приходе судна необходимо заполнить  Код страны для Порта выгрузки</xsl:with-param>
							<xsl:with-param name="DocId" select="$IdSeaAr"/>
							<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/DebarkationPortCountryCode')"/>	
							<xsl:with-param name="Num" select="$RNum"/>					
							<xsl:with-param name="TypeDoc" select="$AdclType"/>
							<xsl:with-param name="PosPkg" select="$AdclPos"/>						
						</xsl:call-template>										
					</xsl:if>	
					<xsl:if test="$decl-HowSend=1 and  string-length(DepartureGoodsPortCountryCode)=0"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr">Для отправки пакета в ПИ в товаре Декларации о грузе при приходе судна необходимо заполнить в Код страны для Порта погрузки</xsl:with-param>
							<xsl:with-param name="DocId" select="$IdSeaAr"/>
							<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/DepartureGoodsPortCountryCode')"/>	
							<xsl:with-param name="Num" select="$RNum"/>					
							<xsl:with-param name="TypeDoc" select="$AdclType"/>
							<xsl:with-param name="PosPkg" select="$AdclPos"/>						
						</xsl:call-template>										
					</xsl:if>	
					<xsl:if test="string-length(GoodsDescription)=0"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с товаром, у которого не заполнено поле Наименование груза .'"/>
							<xsl:with-param name="DocId" select="$IdSeaAr"/>
							<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/GoodsDescription')"/>	
							<xsl:with-param name="Num" select="$RNum"/>					
						<xsl:with-param name="TypeDoc" select="$AdclType"/>
						<xsl:with-param name="PosPkg" select="$AdclPos"/>						
						</xsl:call-template>						
					</xsl:if>							
					<xsl:if test="string-length(GrossWeightQuantity)=0"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с товаром, у которого не заполнено поле Вес товара, брутто (кг).'"/>
							<xsl:with-param name="DocId" select="$IdSeaAr"/>
							<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/GrossWeightQuantity')"/>		
							<xsl:with-param name="Num" select="$RNum"/>				
						<xsl:with-param name="TypeDoc" select="$AdclType"/>
						<xsl:with-param name="PosPkg" select="$AdclPos"/>						
						</xsl:call-template>						
					</xsl:if>	
					<xsl:variable  name="WhCont" select="sum(Container/CONTAINER_ITEM[string-length(Weight)>0]/Weight)"/>
					<xsl:if test="string-length(GrossWeightQuantity)>0 and $WhCont=0 and count(Container/CONTAINER_ITEM[string-length(ContainerID)>0])>0 and number(GrossWeightQuantity)!=$WhCont"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с товаром, у которого Вес товара, брутто (кг) не соответствует весу Груза, указанного в контейнере(ах).'"/>
							<xsl:with-param name="DocId" select="$IdSeaAr"/>
							<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/GrossWeightQuantity')"/>		
							<xsl:with-param name="Num" select="$RNum"/>				
						<xsl:with-param name="TypeDoc" select="$AdclType"/>
						<xsl:with-param name="PosPkg" select="$AdclPos"/>						
						</xsl:call-template>						
					</xsl:if>	
					<xsl:if test="string-length(GrossWeightQuantity)>0">
						<xsl:variable name="err1">
							<xsl:choose>
								<xsl:when test="contains(GrossWeightQuantity,'.')">
									<xsl:if test="string-length(substring-before(GrossWeightQuantity,'.'))>18 or string-length(substring-after(GrossWeightQuantity,'.'))>6">1</xsl:if>
								</xsl:when>
								<xsl:otherwise>
									<xsl:if  test="string-length(GrossWeightQuantity)>24">1</xsl:if>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>	
						<xsl:if  test="$err1=1">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с товаром, у которого значение поля Вес товара, брутто (кг) не соответствует установленному формату.'"/>
								<xsl:with-param name="DocId" select="$IdSeaAr"/>
								<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/GrossWeightQuantity')"/>
								<xsl:with-param name="Num" select="$RNum"/>						
								<xsl:with-param name="TypeDoc" select="$AdclType"/>
								<xsl:with-param name="PosPkg" select="$AdclPos"/>						
							</xsl:call-template>						
						</xsl:if>	
					</xsl:if>	
					<xsl:if test="string-length(PlacesQuantity)=0  and sum(ARRSEADECLGoodsPlaces/ARRSEADECLGOODSPLACES_ITEM[string-length(PackingQuantity)>0]/PackingQuantity)=0 and not($SeaBalast)"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе/отходе судна с товаром, у которого в таблице Количество мест по видам грузовых мест графа Кол-во грузовых мест не заполнено.По умолчанию будет проставлен 0'"/>
							<xsl:with-param name="DocId" select="$IdSeaAr"/>
							<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/ARRSEADECLGoodsPlaces/ARRSEADECLGOODSPLACES_ITEM[1]/PackingQuantity')"/>		
							<xsl:with-param name="Num" select="$RNum"/>				
						<xsl:with-param name="TypeDoc" select="$AdclType"/>
						<xsl:with-param name="PosPkg" select="$AdclPos"/>	
						<xsl:with-param name="Category" select="'WARNING'"/>					
						</xsl:call-template>						
					</xsl:if>
					<!--<xsl:if test="string-length(PlacesQuantity)>0 and number(PlacesQuantity)=0"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с товаром, у которого кол-во грузовых мест равно 0.'"/>
							<xsl:with-param name="DocId" select="$IdSeaAr"/>
							<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/PlacesQuantity')"/>		
							<xsl:with-param name="Num" select="$RNum"/>				
							<xsl:with-param name="TypeDoc" select="$AdclType"/>
							<xsl:with-param name="PosPkg" select="$AdclPos"/>						
						</xsl:call-template>						
					</xsl:if>-->
					<xsl:if test="string-length(PlacesQuantity)>8"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с товаром, у которого число кол-ва грузовых мест более 8 знаков.'"/>
							<xsl:with-param name="DocId" select="$IdSeaAr"/>
							<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/PlacesQuantity')"/>
							<xsl:with-param name="Num" select="$RNum"/>						
						<xsl:with-param name="TypeDoc" select="$AdclType"/>
						<xsl:with-param name="PosPkg" select="$AdclPos"/>						
						</xsl:call-template>						
					</xsl:if>
					<xsl:if test="string-length(UNNO)>0 and string-length(UNNO)!=4"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с товаром, у которого длина Кода UNNO не равна 4 знакам.'"/>
							<xsl:with-param name="DocId" select="$IdSeaAr"/>
							<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/UNNO')"/>		
							<xsl:with-param name="Num" select="$RNum"/>				
						<xsl:with-param name="TypeDoc" select="$AdclType"/>
						<xsl:with-param name="PosPkg" select="$AdclPos"/>						
						</xsl:call-template>						
					</xsl:if>
					<xsl:if test="string-length(Consignor_CountryCode)>0"> 
						<xsl:variable name="CnorCr" select="Consignor_CountryCode"/>
						<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$CnorCr]/Name)=0">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с товаром, у которого Код страны отправителя заполнен неверно.'"/>
								<xsl:with-param name="DocId" select="$IdSeaAr"/>
								<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/Consignor_CountryCode')"/>
								<xsl:with-param name="Num" select="$RNum"/>						
						<xsl:with-param name="TypeDoc" select="$AdclType"/>
						<xsl:with-param name="PosPkg" select="$AdclPos"/>						
							</xsl:call-template>						
						</xsl:if>	
					</xsl:if>
					<xsl:if test="string-length(Consignee_CountryCode)>0"> 
						<xsl:variable name="CneeCr" select="Consignee_CountryCode"/>
						<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$CneeCr]/Name)=0">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с товаром, у которого Код страны получателя заполнен неверно.'"/>
								<xsl:with-param name="DocId" select="$IdSeaAr"/>
								<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/Consignee_CountryCode')"/>
								<xsl:with-param name="Num" select="$RNum"/>						
								<xsl:with-param name="TypeDoc" select="$AdclType"/>
								<xsl:with-param name="PosPkg" select="$AdclPos"/>						
							</xsl:call-template>						
						</xsl:if>	
					</xsl:if>
					<xsl:for-each select="Container/CONTAINER_ITEM[string-length(ContainerID)>0]">
						<xsl:variable name="ContPos" select="position()"/>
						<xsl:variable name="ValidCont">
							<xsl:call-template name="ValidContainerNum">
								<xsl:with-param name="Nums" select="ContainerID"/>
								<xsl:with-param name="notSea" select="0"/>
							</xsl:call-template>
						</xsl:variable>
						<xsl:if test="$ValidCont=0">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит документ Коносамент с товаром, в котором № контейнера - не соответствует формату ХХХХ9999999'"/>
								<xsl:with-param name="DocId" select="$IdSeaAr"/>
								<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/Container/CONTAINER_ITEM[',$ContPos,']/ContainerID')"/>						
								<xsl:with-param name="Category" select="'WARNING'"/>					
								<xsl:with-param name="Num" select="$RNum"/>
								<xsl:with-param name="TypeDoc" select="$AdclType"/>
								<xsl:with-param name="PosPkg" select="$AdclPos"/>						
							</xsl:call-template>		
						</xsl:if>
					</xsl:for-each>
					<xsl:for-each select="ARRSEADECLGoodsPlaces/ARRSEADECLGOODSPLACES_ITEM[string-length(PackingCode)>0]">
							<xsl:variable name="Pk" select="PackingCode"/>
							<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Packing_ITEM[ID=$Pk]/Name)=0">
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при приходе судна с товаром, у которого код вида упаковки заполнен неверно.'"/>
										<xsl:with-param name="DocId" select="$IdSeaAr"/>
										<xsl:with-param name="PathErr" select="concat('ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM[',$ArrSeaDclGoods,']/ARRSEADECLGoodsPlaces/ARRSEADECLGOODSPLACES_ITEM[',position(),']/PackingCode')"/>
									<xsl:with-param name="Num" select="$RNum"/>						
									<xsl:with-param name="TypeDoc" select="$AdclType"/>
									<xsl:with-param name="PosPkg" select="$AdclPos"/>						
								</xsl:call-template>
							</xsl:if>
						</xsl:for-each>	
				</xsl:for-each>
			</xsl:for-each>
	
			<xsl:for-each select="//CONOSAMENT/CONOSAMENT_ITEM[(../@ctmtd:CfgName)!='SEAPIT1.CFG.XML'  and  (../@ctmtd:CfgName)!='seapit1.cfg.xml']">
				<xsl:variable name="IdConos" select="../@id"/> 
				<xsl:variable name="CnsPos" select="position()"/>
				<xsl:variable name="CnsType" select="../@ctmtd:CfgName"/>  
				<xsl:variable name="NameNode" select ="CONOSAMENTGoods/*[name()='CONOSAMENTGOODS_ITEM' or name()='CONOSAMENTGoods_ITEM']"/>
				<xsl:variable name="Proc" select="Procedure"/>
				<xsl:variable name="ProcDic" select="document('../../../NSI/TranspNSIXml.xml')//OTAMREG_ITEM[KOD=$Proc]/NAIM"/>
				<xsl:variable name="ValCod" select="CurrencyCode"/>
				<xsl:variable name="ValDic" select="document('../../../NSI/TranspNSIXml.xml')//Currency_ITEM[ABBR=$ValCod]/Code"/>
				<xsl:variable name="Weight" select="number(sum($NameNode[number(GrossWeightQuantity)>0]/GrossWeightQuantity))"/>	
				<xsl:variable name="RNum" select="RegNum"/>
				<xsl:variable name="RID1" select="normalize-space(PI_RegID)"/>
				<xsl:variable name="ValidRID1">
					<xsl:call-template name="ValidUIN_NUM">
						<xsl:with-param name="UIN">
							<xsl:call-template name="ClearSimUIN_NUM">
								<xsl:with-param name="UIN" select="normalize-space($RID1)"/>
							</xsl:call-template>
						</xsl:with-param>	
					</xsl:call-template>
				</xsl:variable>
				<xsl:if test="string-length($RID1)>0 and $ValidRID1=0 and $NotInvSea">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит Коносамент, у которого длина значения поля Таможенный идентификационный номер (УИН ПИТ) не соответствует установленному формату (по длине). Документ будет отправлен в ФТС без данного номера.'"/>
						<xsl:with-param name="DocId" select="$IdConos"/>
						<xsl:with-param name="PathErr" select="'CONOSAMENT/CONOSAMENT_ITEM/PI_RegID'"/>						
						<xsl:with-param name="Category" select="'WARNING'"/>	
						<xsl:with-param name="TypeDoc" select="$CnsType"/>
						<xsl:with-param name="PosPkg" select="$CnsPos"/>
						<xsl:with-param name="Num" select="$RNum"/>	
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="string-length(RegNum)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит Коносамент, у которого Регистрационный номер  не заполнен .'"/>
						<xsl:with-param name="DocId" select="$IdConos"/>
						<xsl:with-param name="PathErr" select="'CONOSAMENT/CONOSAMENT_ITEM/RegNum'"/>						
						<xsl:with-param name="Category" select="'ERROR'"/>	
						<xsl:with-param name="TypeDoc" select="$CnsType"/>
						<xsl:with-param name="PosPkg" select="$CnsPos"/>						
					</xsl:call-template>						
				</xsl:if>
				
				<xsl:if test="count(//ARRSEADECL/ARRSEADECL_ITEM)>0 and count(//ARRSEADECLGOODS_ITEM[ConosamentNum=$RNum])=0  and $NotInvSea"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит Коносамент, который отсутствует в Декларации о грузе при приходе/отходе судна.'"/>
						<xsl:with-param name="DocId" select="$IdConos"/>
						<xsl:with-param name="PathErr" select="'CONOSAMENT/CONOSAMENT_ITEM/RegNum'"/>						
						<xsl:with-param name="Category" select="'ERROR'"/>	
						<xsl:with-param name="TypeDoc" select="$CnsType"/>
						<xsl:with-param name="PosPkg" select="$CnsPos"/>	
						<xsl:with-param name="Num" select="$RNum"/>					
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="string-length(Consignee_CountryCode)>0"> 
					<xsl:variable name="CneeCr" select="Consignee_CountryCode"/>
					<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$CneeCr]/Name)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Коносамент, у которого Код страны получателя заполнен неверно.'"/>
							<xsl:with-param name="DocId" select="$IdConos"/>
							<xsl:with-param name="PathErr" select="'CONOSAMENT/CONOSAMENT_ITEM/Consignee_CountryCode'"/>						
							<xsl:with-param name="Category" select="'ERROR'"/>
							<xsl:with-param name="Num" select="$RNum"/>
						<xsl:with-param name="TypeDoc" select="$CnsType"/>
						<xsl:with-param name="PosPkg" select="$CnsPos"/>						
						</xsl:call-template>						
					</xsl:if>	
				</xsl:if>
				<xsl:if test="string-length(Consignor_CountryCode)>0"> 
					<xsl:variable name="CnorCr" select="Consignor_CountryCode"/>
					<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$CnorCr]/Name)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Коносамент, у которого Отправитель: Код страны  заполнен неверно.'"/>
							<xsl:with-param name="DocId" select="$IdConos"/>
							<xsl:with-param name="PathErr" select="'CONOSAMENT/CONOSAMENT_ITEM/Consignor_CountryCode'"/>						
							<xsl:with-param name="Category" select="'ERROR'"/>
							<xsl:with-param name="Num" select="$RNum"/>
						<xsl:with-param name="TypeDoc" select="$CnsType"/>
						<xsl:with-param name="PosPkg" select="$CnsPos"/>						
						</xsl:call-template>						
					</xsl:if>	
				</xsl:if>
				<xsl:if test="string-length(VesselName)=0">	
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ Коносамент с не заполненным полем Наименование судна.'"/>
						<xsl:with-param name="DocId" select="$IdConos"/>
						<xsl:with-param name="PathErr" select="'CONOSAMENT/CONOSAMENT_ITEM/VesselName'"/>						
						<xsl:with-param name="Category" select="'ERROR'"/>						
						<xsl:with-param name="Num" select="$RNum"/>
						<xsl:with-param name="TypeDoc" select="$CnsType"/>
						<xsl:with-param name="PosPkg" select="$CnsPos"/>						
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="string-length(LoadingName)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ Коносамент с не заполненным полем Погрузка груза: название порта.'"/>
						<xsl:with-param name="DocId" select="$IdConos"/>
						<xsl:with-param name="PathErr" select="'CONOSAMENT/CONOSAMENT_ITEM/LoadingName'"/>						
						<xsl:with-param name="Category" select="'ERROR'"/>						
						<xsl:with-param name="Num" select="$RNum"/>
						<xsl:with-param name="TypeDoc" select="$CnsType"/>
						<xsl:with-param name="PosPkg" select="$CnsPos"/>						
					</xsl:call-template>						
				</xsl:if>
				<xsl:variable name="LCr" select="Loading_CountryCode"/>
				<xsl:if test="string-length($LCr)>0 and string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$LCr]/ABC2)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ Коносамент, с неверно заполненным полем Погрузка груза: код страны.'"/>
						<xsl:with-param name="DocId" select="$IdConos"/>
						<xsl:with-param name="PathErr" select="'CONOSAMENT/CONOSAMENT_ITEM/Loading_CountryCode'"/>						
						<xsl:with-param name="Category" select="'ERROR'"/>						
						<xsl:with-param name="Num" select="$RNum"/>
						<xsl:with-param name="TypeDoc" select="$CnsType"/>
						<xsl:with-param name="PosPkg" select="$CnsPos"/>						
					</xsl:call-template>						
				</xsl:if>
				<xsl:variable name="LCrN" select="Loading_CountryName"/>
				<xsl:if test="string-length($LCrN)>0 and string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[Name=$LCrN]/Name)=0 and string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[EngName=$LCrN]/EngName)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ Коносамент, с неверно заполненным полем Погрузка груза: наименование страны.'"/>
						<xsl:with-param name="DocId" select="$IdConos"/>
						<xsl:with-param name="PathErr" select="'CONOSAMENT/CONOSAMENT_ITEM/Loading_CountryName'"/>						
						<xsl:with-param name="Category" select="'ERROR'"/>						
						<xsl:with-param name="Num" select="$RNum"/>
						<xsl:with-param name="TypeDoc" select="$CnsType"/>
						<xsl:with-param name="PosPkg" select="$CnsPos"/>						
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="string-length(UnloadingName)=0">	
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select=" 'Пакет содержит документ Коносамент с не заполненным полем  Разрузка груза: название порта.'"/>
						<xsl:with-param name="DocId" select="$IdConos"/>
						<xsl:with-param name="PathErr" select="'CONOSAMENT/CONOSAMENT_ITEM/UnloadingName'"/>						
						<xsl:with-param name="Category" select="'ERROR'"/>						
						<xsl:with-param name="Num" select="$RNum"/>
						<xsl:with-param name="TypeDoc" select="$CnsType"/>
						<xsl:with-param name="PosPkg" select="$CnsPos"/>						
					</xsl:call-template>						
				</xsl:if>
				<xsl:variable name="UnCr" select="Unloading_CountryCode"/>
				<xsl:if test="string-length($LCr)>0 and string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$UnCr]/ABC2)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ Коносамент, с неверно заполненным полем Разрузка груза: код страны.'"/>
						<xsl:with-param name="DocId" select="$IdConos"/>
						<xsl:with-param name="PathErr" select="'CONOSAMENT/CONOSAMENT_ITEM/Unloading_CountryCode'"/>						
						<xsl:with-param name="Category" select="'ERROR'"/>						
						<xsl:with-param name="Num" select="$RNum"/>
						<xsl:with-param name="TypeDoc" select="$CnsType"/>
						<xsl:with-param name="PosPkg" select="$CnsPos"/>						
					</xsl:call-template>						
				</xsl:if>
				<xsl:variable name="UnCrN" select="Unloading_CountryName"/>
				<xsl:if test="string-length($LCrN)>0 and string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[Name=$UnCrN]/Name)=0 and string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[EngName=$UnCrN]/EngName)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ Коносамент, с неверно заполненным полем Разрузка груза: наименование страны.'"/>
						<xsl:with-param name="DocId" select="$IdConos"/>
						<xsl:with-param name="PathErr" select="'CONOSAMENT/CONOSAMENT_ITEM/Unloading_CountryName'"/>						
						<xsl:with-param name="Category" select="'ERROR'"/>						
						<xsl:with-param name="Num" select="$RNum"/>
						<xsl:with-param name="TypeDoc" select="$CnsType"/>
						<xsl:with-param name="PosPkg" select="$CnsPos"/>						
					</xsl:call-template>						
				</xsl:if>
				<xsl:for-each select="$NameNode">
					<xsl:variable name="PosConosGoods" select="position()"/> 
					<xsl:variable name="NodeErr1" select="name($NameNode)"/>
					<xsl:variable name="NodeErr" select="concat('CONOSAMENT/CONOSAMENT_ITEM/CONOSAMENTGoods/',$NodeErr1,'[',$PosConosGoods,']/')"/>
					<xsl:if test="string-length(GoodsDescription)=0"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит документ Коносамент с товаром, в котором не заполнено поле Наименование груза.'"/>
							<xsl:with-param name="DocId" select="$IdConos"/>
							<xsl:with-param name="PathErr" select="concat($NodeErr,'GoodsDescription')"/>						
							<xsl:with-param name="Category" select="'ERROR'"/>						
							<xsl:with-param name="Num" select="$RNum"/>
						<xsl:with-param name="TypeDoc" select="$CnsType"/>
						<xsl:with-param name="PosPkg" select="$CnsPos"/>						
						</xsl:call-template>						
					</xsl:if>
					<xsl:choose>
						<xsl:when test="count(Danger/DANGER_ITEM[string-length(DangerIMO)>0])>0 or count(Danger/DANGER_ITEM[string-length(UNNO)>0])>0">
							<xsl:for-each select="Danger/DANGER_ITEM[string-length(DangerIMO)>0]">
								<xsl:variable name="PDnImo" select="position()"/>
								<xsl:if test="string-length(DangerIMO)>3">	
									<xsl:call-template name="ErrorNode">
										<xsl:with-param name="MessErr" select="'Пакет содержит документ Коносамент с товаром, в котором длина значения поля класс опасности более 3 знаков.'"/>
										<xsl:with-param name="DocId" select="$IdConos"/>
										<xsl:with-param name="PathErr" select="concat($NodeErr,'Danger/DANGER_ITEM[',$PDnImo,']/DangerIMO')"/>						
										<xsl:with-param name="Category" select="'ERROR'"/>
										<xsl:with-param name="Num" select="$RNum"/>
										<xsl:with-param name="TypeDoc" select="$CnsType"/>
										<xsl:with-param name="PosPkg" select="$CnsPos"/>									
									</xsl:call-template>						
								</xsl:if>
							</xsl:for-each>
							<xsl:for-each select="Danger/DANGER_ITEM[string-length(UNNO)>0]">
								<xsl:variable name="PDnImo" select="position()"/>
								<xsl:if test="string-length(UNNO)>0 and  string-length(UNNO)!=4">		
									<xsl:call-template name="ErrorNode">
										<xsl:with-param name="MessErr" select="'Пакет содержит документ Коносамент с товаром, в котором длина значения поля Идентификатор опасности вещества по классифкации ООН не равна 4 знакам'"/>
										<xsl:with-param name="DocId" select="$IdConos"/>
										<xsl:with-param name="PathErr" select="concat($NodeErr,'Danger/DANGER_ITEM[',$PDnImo,']/UNNO')"/>						
										<xsl:with-param name="Category" select="'ERROR'"/>	
										<xsl:with-param name="Num" select="$RNum"/>
								<xsl:with-param name="TypeDoc" select="$CnsType"/>
								<xsl:with-param name="PosPkg" select="$CnsPos"/>								
									</xsl:call-template>						
								</xsl:if>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="string-length(DangerIMO)>3">	
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ Коносамент с товаром, в котором длина значения поля класс опасности  более 3 знаков.'"/>
									<xsl:with-param name="DocId" select="$IdConos"/>
									<xsl:with-param name="PathErr" select="concat($NodeErr,'DangerIMO')"/>						
									<xsl:with-param name="Category" select="'ERROR'"/>						
									<xsl:with-param name="Num" select="$RNum"/>
								<xsl:with-param name="TypeDoc" select="$CnsType"/>
								<xsl:with-param name="PosPkg" select="$CnsPos"/>						
								</xsl:call-template>						
							</xsl:if>
							<xsl:if test="string-length(UNNO)>0 and  string-length(UNNO)!=4">	
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ Коносамент с товаром, в котором длина значения поля Идентификатор опасности вещества по классифкации ООН не равна 4 знакам.'"/>
									<xsl:with-param name="DocId" select="$IdConos"/>
									<xsl:with-param name="PathErr" select="concat($NodeErr,'UNNO')"/>						
									<xsl:with-param name="Category" select="'ERROR'"/>						
									<xsl:with-param name="Num" select="$RNum"/>
								<xsl:with-param name="TypeDoc" select="$CnsType"/>
								<xsl:with-param name="PosPkg" select="$CnsPos"/>						
								</xsl:call-template>						
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:if test="string-length(GrossWeightQuantity)=0">	
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит документ Коносамент с товаром, в котором не заполнено поле Вес товара, брутто (кг).'"/>
							<xsl:with-param name="DocId" select="$IdConos"/>
							<xsl:with-param name="PathErr" select="concat($NodeErr,'GrossWeightQuantity')"/>						
							<xsl:with-param name="Category" select="'ERROR'"/>						
							<xsl:with-param name="Num" select="$RNum"/>
						<xsl:with-param name="TypeDoc" select="$CnsType"/>
						<xsl:with-param name="PosPkg" select="$CnsPos"/>						
						</xsl:call-template>						
					</xsl:if>
					<xsl:if test="string-length(GrossWeightQuantity)>0">
						<xsl:variable name="err1">
							<xsl:choose>
								<xsl:when test="contains(GrossWeightQuantity,'.')">
									<xsl:if test="string-length(substring-before(GrossWeightQuantity,'.'))>18 or string-length(substring-after(GrossWeightQuantity,'.'))>6">1</xsl:if>
								</xsl:when>
								<xsl:otherwise>
									<xsl:if  test="string-length(GrossWeightQuantity)>24">1</xsl:if>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>	
						<xsl:if  test="$err1=1">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит документ Коносамент с товаром, у которого значение поля Вес товара, брутто (кг) не соответствует установленному формату.'"/>
								<xsl:with-param name="DocId" select="$IdConos"/>
								<xsl:with-param name="PathErr" select="concat($NodeErr,'GrossWeightQuantity')"/>
								<xsl:with-param name="Num" select="$RNum"/>						
						<xsl:with-param name="TypeDoc" select="$CnsType"/>
						<xsl:with-param name="PosPkg" select="$CnsPos"/>						
							</xsl:call-template>						
						</xsl:if>	
					</xsl:if>			
					<xsl:variable name="CNum" select="ContainerNum"/>
					<xsl:if test="string-length(ContainerNum)>0 and count(ARRSEADECL/ARRSEADECL_ITEM/ARRSEADECLGoods/ARRSEADECLGOODS_ITEM/Container/CONTAINER_ITEM[ContainerID=$CNum])=0">
						<xsl:variable name="ValidCont">
							<xsl:call-template name="ValidContainerNum">
								<xsl:with-param name="Nums" select="ContainerNum"/>
								<xsl:with-param name="notSea" select="0"/>
							</xsl:call-template>
						</xsl:variable>
						<xsl:if test="$ValidCont=0">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит документ Коносамент с товаром, в котором № контейнера - не соответствует формату ХХХХ9999999'"/>
								<xsl:with-param name="DocId" select="$IdConos"/>
								<xsl:with-param name="PathErr" select="concat($NodeErr,'ContainerNum')"/>						
								<xsl:with-param name="Category" select="'WARNING'"/>					
								<xsl:with-param name="Num" select="$RNum"/>
								<xsl:with-param name="TypeDoc" select="$CnsType"/>
								<xsl:with-param name="PosPkg" select="$CnsPos"/>						
							</xsl:call-template>		
						</xsl:if>				
					</xsl:if>
				</xsl:for-each>	
			</xsl:for-each>	
			
			<xsl:for-each select="//DEPSEADECL/DEPSEADECL_ITEM">
		
				<xsl:variable name="IdSeaDp" select="../@id"/>
				<xsl:variable name="DpSPos" select="position()"/>
				<xsl:variable name="DpSType" select="../@ctmtd:CfgName"/>  
				<xsl:if test="string-length(DestinationPort)=0">	
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при отходе судна с не заполненным полем Название порта назначения судна.'"/>
						<xsl:with-param name="DocId" select="$IdSeaDp"/>
						<xsl:with-param name="PathErr" select="'DEPSEADECL/DEPSEADECL_ITEM/DestinationPort'"/>						
						<xsl:with-param name="TypeDoc" select="$DpSType"/>
						<xsl:with-param name="PosPkg" select="$DpSPos"/>						
					</xsl:call-template>						
				</xsl:if>
				<xsl:if  test="$AllFlk=1">
					<xsl:if test="string-length(DocSig_PersonName)=0 and string-length(//GENERALDECL/GENERALDECL_ITEM/DocSig_PersonName)=0  and $NotInvSea">	
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при отходе судна с не заполненным полем Фамилия в разделе Подпись документа... .'"/>
							<xsl:with-param name="DocId" select="$IdSeaDp"/>
							<xsl:with-param name="PathErr" select="'DEPSEADECL/DEPSEADECL_ITEM/DocSig_PersonName'"/>						
						<xsl:with-param name="TypeDoc" select="$DpSType"/>
						<xsl:with-param name="PosPkg" select="$DpSPos"/>						
						</xsl:call-template>						
					</xsl:if>
					<xsl:if test="string-length(DocSig_PersonName2)=0 and string-length(//GENERALDECL/GENERALDECL_ITEM/DocSig_PersonName2)=0  and $AllFlk!=5"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при отходе судна с не заполненным полем Имя в разделе Подпись документа... .'"/>
							<xsl:with-param name="DocId" select="$IdSeaDp"/>
							<xsl:with-param name="PathErr" select="'DEPSEADECL/DEPSEADECL_ITEM/DocSig_PersonName2'"/>						
						<xsl:with-param name="TypeDoc" select="$DpSType"/>
						<xsl:with-param name="PosPkg" select="$DpSPos"/>						
						</xsl:call-template>						
					</xsl:if>	
				</xsl:if>	
				<xsl:if test="string-length(VesselName)=0">	
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при отходе судна с не заполненным полем Наименование судна.'"/>
						<xsl:with-param name="DocId" select="$IdSeaDp"/>
						<xsl:with-param name="PathErr" select="'DEPSEADECL/DEPSEADECL_ITEM/VesselName'"/>						
						<xsl:with-param name="TypeDoc" select="$DpSType"/>
						<xsl:with-param name="PosPkg" select="$DpSPos"/>						
					</xsl:call-template>						
				</xsl:if>
				<xsl:for-each select="DEPSEADECLGoods/DEPSEADECLGOODS_ITEM">
					<xsl:variable name="DepSeaDclGoods" select="position()"/>
					<xsl:variable name="RNum" select="ConosamentNum"/>
					<xsl:if test="string-length(GoodsDescription)=0"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при отходе судна с товаром, у которого не заполнено поле Наименование груза .'"/>
							<xsl:with-param name="DocId" select="$IdSeaDp"/>
							<xsl:with-param name="PathErr" select="concat('DEPSEADECL/DEPSEADECL_ITEM/DEPSEADECLGoods/DEPSEADECLGOODS_ITEM[',$DepSeaDclGoods,']/GoodsDescription')"/>						
						<xsl:with-param name="TypeDoc" select="$DpSType"/>
						<xsl:with-param name="PosPkg" select="$DpSPos"/>						
						</xsl:call-template>						
					</xsl:if>
					<xsl:if test="string-length(GoodsTNVEDCode)>0 and (string-length(GoodsTNVEDCode)&lt;4 or string-length(GoodsTNVEDCode)>10)">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при отходе судна с товаром,  у которого значение поля Код товара по ТН ВЭД не соответствует установленному формату .'"/>
							<xsl:with-param name="DocId" select="$IdSeaDp"/>
							<xsl:with-param name="PathErr" select="concat('DEPSEADECL/DEPSEADECL_ITEM/DEPSEADECLGoods/DEPSEADECLGOODS_ITEM[',$DepSeaDclGoods,']/GoodsTNVEDCode')"/>						
						<xsl:with-param name="TypeDoc" select="$DpSType"/>
						<xsl:with-param name="PosPkg" select="$DpSPos"/>						
						</xsl:call-template>						
					</xsl:if>							
					<xsl:if test="string-length(GrossWeightQuantity)=0"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при отходе судна с товаром, у которого не заполнено или значение равно 0 поле Вес товара, брутто (кг).'"/>
							<xsl:with-param name="DocId" select="$IdSeaDp"/>
							<xsl:with-param name="PathErr" select="concat('DEPSEADECL/DEPSEADECL_ITEM/DEPSEADECLGoods/DEPSEADECLGOODS_ITEM[',$DepSeaDclGoods,']/GrossWeightQuantity')"/>						
						<xsl:with-param name="TypeDoc" select="$DpSType"/>
						<xsl:with-param name="PosPkg" select="$DpSPos"/>						
						</xsl:call-template>						
					</xsl:if>	
					<xsl:if test="string-length(GrossWeightQuantity)>0">
						<xsl:variable name="err1">
							<xsl:choose>
								<xsl:when test="contains(GrossWeightQuantity,'.')">
									<xsl:if test="string-length(substring-before(GrossWeightQuantity,'.'))>18 or string-length(substring-after(GrossWeightQuantity,'.'))>6">1</xsl:if>
								</xsl:when>
								<xsl:otherwise>
									<xsl:if  test="string-length(GrossWeightQuantity)>24">1</xsl:if>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>	
						<xsl:if  test="$err1=1">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при отходе судна с товаром, у которого значение поля Вес товара, брутто (кг) не соответствует установленному формату.'"/>
								<xsl:with-param name="DocId" select="$IdSeaDp"/>
								<xsl:with-param name="PathErr" select="concat('DEPSEADECL/DEPSEADECL_ITEM/DEPSEADECLGoods/DEPSEADECLGOODS_ITEM[',$DepSeaDclGoods,']/GrossWeightQuantity')"/>	
								<xsl:with-param name="Num" select="$RNum"/>						
						<xsl:with-param name="TypeDoc" select="$DpSType"/>
						<xsl:with-param name="PosPkg" select="$DpSPos"/>						
							</xsl:call-template>						
						</xsl:if>	
					</xsl:if>			
					<xsl:if test="string-length(PlacesQuantity)>8"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при отходе судна с товаром, у которого число кол-ва грузовых мест более 8 знаков.'"/>
							<xsl:with-param name="DocId" select="$IdSeaDp"/>
							<xsl:with-param name="PathErr" select="concat('DEPSEADECL/DEPSEADECL_ITEM/DEPSEADECLGoods/DEPSEADECLGOODS_ITEM[',$DepSeaDclGoods,']/PlacesQuantity')"/>	
							<xsl:with-param name="Num" select="$RNum"/>						
						<xsl:with-param name="TypeDoc" select="$DpSType"/>
						<xsl:with-param name="PosPkg" select="$DpSPos"/>						
						</xsl:call-template>						
					</xsl:if>
					<xsl:for-each select="DEPSEADECLGoodsPlaces/DEPSEADECLGOODSPLACES_ITEM[string-length(PackingCode)>0]">
						<xsl:variable name="PkDep" select="PackingCode"/>
						<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Packing_ITEM[ID=$PkDep]/Name)=0">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит Декларацию о грузе при отходе судна с товаром, у которого код вида упаковки заполнен неверно.'"/>
								<xsl:with-param name="DocId" select="$IdSeaDp"/>
								<xsl:with-param name="PathErr" select="concat('DEPSEADECL/DEPSEADECL_ITEM/DEPSEADECLGoods/DEPSEADECLGOODS_ITEM[',$DepSeaDclGoods,']/DEPSEADECLGoodsPlaces/DEPSEADECLGOODSPLACES_ITEM[',position(),']/PackingCode')"/>
								<xsl:with-param name="Num" select="$RNum"/>						
						<xsl:with-param name="TypeDoc" select="$DpSType"/>
						<xsl:with-param name="PosPkg" select="$DpSPos"/>						
							</xsl:call-template>
							</xsl:if>
						</xsl:for-each>	
				</xsl:for-each>
			</xsl:for-each>
			
			<xsl:for-each select="//LISTUIN/LISTUIN_ITEM[*[not(contains(@*[local-name()='CfgName'],'REQLISTUIN'))]]">
				<xsl:variable name="IdUin" select="../@id"/>
				<xsl:variable name="UinPos" select="position()"/>
				<xsl:variable name="UinType" select="../@ctmtd:CfgName"/> 
				<!--<xsl:if test="count(//NUMUIN/NUMUIN_ITEM[string-length(UIN_ID)>0 and string-length(ConosamentNum)>0])=0">	
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит пустой Реестр УИН ПИТ в ПДС.'"/>
						<xsl:with-param name="DocId" select="$IdUin"/>
						<xsl:with-param name="PathErr" select="'LISTUIN/LISTUIN_ITEM/NUMUIN/NUMUIN_ITEM[1]/ConosamentNum'"/>						
						<xsl:with-param name="TypeDoc" select="$UinType"/>
						<xsl:with-param name="PosPkg" select="$UinPos"/>						
					</xsl:call-template>						
				</xsl:if>-->
				<xsl:for-each select="NUMUIN/NUMUIN_ITEM">
					<xsl:variable name="CnNum" select="ConosamentNum"/>
					<xsl:variable name="UINID" select="UIN_ID"/>
					<xsl:if test="string-length(UIN_ID)=0 and string-length(ConosamentNum)>0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Реестр УИН ПИТ в ПДС с не заполненным УИН ПИТ товарной партии. Заполните УИН ПИТ или удалите строку реестра'"/>
							<xsl:with-param name="DocId" select="$IdUin"/>
							<xsl:with-param name="PathErr" select="concat('LISTUIN/LISTUIN_ITEM/NUMUIN/NUMUIN_ITEM[',position(),']/UIN_ID')"/>
							<xsl:with-param name="TypeDoc" select="$UinType"/>
							<xsl:with-param name="PosPkg" select="$UinPos"/>						
						</xsl:call-template>						
					</xsl:if>
					<xsl:if test="string-length(UIN_ID)>0 and string-length(ConosamentNum)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит Реестр УИН ПИТ в ПДС с не заполненным номером Коносамента . Заполните номер Коносамента или удалите строку реестра'"/>
							<xsl:with-param name="DocId" select="$IdUin"/>
							<xsl:with-param name="PathErr" select="concat('LISTUIN/LISTUIN_ITEM/NUMUIN/NUMUIN_ITEM[',position(),']/ConosamentNum')"/>
							<xsl:with-param name="TypeDoc" select="$UinType"/>
							<xsl:with-param name="PosPkg" select="$UinPos"/>						
						</xsl:call-template>						
					</xsl:if>
					<xsl:variable name="CountBill" select="//NUMUIN_ITEM[generate-id(.)=generate-id(key('ConocamentUINPIT',concat($CnNum,./UIN_ID)))][string-length(ConosamentNum)>0][string-length(UIN_ID)>0]"/>
					<xsl:variable name="CountUin" select="//NUMUIN_ITEM[generate-id(.)=generate-id(key('ConocamentUINPIT',concat(./ConosamentNum,$UINID)))][string-length(UIN_ID)>0][string-length(ConosamentNum)>0]"/>
					<xsl:if test="count($CountBill/UIN_ID)>1">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr">
								<xsl:value-of select="concat('Пакет содержит Реестр УИН ПИТ в ПДС Коносамент ',$CnNum,', которому соответсвуют ',count($CountBill/UIN_ID),' УИН ПИТ:')"/>
								<xsl:for-each select="$CountBill/UIN_ID">
									<xsl:value-of select="."/>
									<xsl:if test="position()!=last()">, </xsl:if>
								</xsl:for-each>
							</xsl:with-param>
							<xsl:with-param name="DocId" select="$IdUin"/>
							<xsl:with-param name="PathErr" select="concat('LISTUIN/LISTUIN_ITEM/NUMUIN/NUMUIN_ITEM[',position(),']/UIN_ID')"/>
							<xsl:with-param name="TypeDoc" select="$UinType"/>
							<xsl:with-param name="PosPkg" select="$UinPos"/>						
						</xsl:call-template>						
					</xsl:if>
					<xsl:if test="string-length($CnNum)>0 and ((count(//CONOSAMENT)=0 and  count(//ARRSEADECLGOODS_ITEM[normalize-space(ConosamentNum)=$CnNum])=0) or  (count(//CONOSAMENT)>0 and count(//CONOSAMENT/CONOSAMENT_ITEM[RegNum=$CnNum])=0))">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat('Пакет содержит Реестр УИН/ПИТ в ПДС с номером Коносамента ',$CnNum,', который не указан в  Декларацию о грузе при приходе/отходе судна, или в пакете отсутствует документ Коносамент с таким номером')"/>
							<xsl:with-param name="DocId" select="$IdUin"/>
							<xsl:with-param name="PathErr" select="concat('LISTUIN/LISTUIN_ITEM/NUMUIN/NUMUIN_ITEM[',position(),']/ConosamentNum')"/>
							<xsl:with-param name="TypeDoc" select="$UinType"/>
							<xsl:with-param name="PosPkg" select="$UinPos"/>						
						</xsl:call-template>						
					</xsl:if>
					<xsl:variable name="ValidUINID">
						<xsl:call-template name="ValidUIN_NUM">
							<xsl:with-param name="UIN">
								<xsl:call-template name="ClearSimUIN_NUM">
									<xsl:with-param name="UIN" select="normalize-space($UINID)"/>
								</xsl:call-template>
							</xsl:with-param>	
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="string-length($UINID)>0 and $ValidUINID=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat('Пакет содержит Реестр УИН/ПИТ в ПДС с УИН товарной партии ',$UINID,', который не соответствует установленному формату (по длине). Документ будет отправлен в ФТС без данного номера')"/>
							<xsl:with-param name="DocId" select="$IdUin"/>
							<xsl:with-param name="PathErr" select="concat('LISTUIN/LISTUIN_ITEM/NUMUIN/NUMUIN_ITEM[',position(),']/UIN_ID')"/>
							<xsl:with-param name="TypeDoc" select="$UinType"/>
							<xsl:with-param name="PosPkg" select="$UinPos"/>
							<xsl:with-param name="Category" select="'WARNING'"/>						
						</xsl:call-template>						
					</xsl:if>
					<xsl:if test="count($CountUin/ConosamentNum)>1">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr">
								<xsl:value-of select="concat('Пакет содержит Реестр УИН ПИТ в ПДС с номером УИН ПИТ ',$UINID,', которому соответсвуют ',count($CountUin/ConosamentNum),' Коносамента(ов) :')"/>
								<xsl:for-each select="$CountUin/ConosamentNum">
									<xsl:value-of select="."/>
									<xsl:if test="position()!=last()">, </xsl:if>
								</xsl:for-each>
							</xsl:with-param>
							<xsl:with-param name="DocId" select="$IdUin"/>
							<xsl:with-param name="PathErr" select="concat('LISTUIN/LISTUIN_ITEM/NUMUIN/NUMUIN_ITEM[',position(),']/UIN_ID')"/>
							<xsl:with-param name="TypeDoc" select="$UinType"/>
							<xsl:with-param name="PosPkg" select="$UinPos"/>
							<xsl:with-param name="Category" select="'WARNING'"/>								
						</xsl:call-template>						
					</xsl:if>
					<xsl:if test="string-length($CnNum)>0 and string-length($UINID)>0 and count(//ARRSEADECLGOODS_ITEM[normalize-space(ConosamentNum)=$CnNum and string-length(ConosamentID)>0  and ConosamentID=$UINID])=0 and count(//ARRSEADECLGOODS_ITEM[normalize-space(ConosamentNum)=$CnNum and string-length(ConosamentID)>0])>0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat('Пакет содержит Реестр УИН/ПИТ в ПДС с номером Коносамента ',$CnNum,', для которого указан УИН ПИТ ',$UINID,' не соответствующий указанному в  Декларацию о грузе при приходе/отходе судна')"/>
							<xsl:with-param name="DocId" select="$IdUin"/>
							<xsl:with-param name="PathErr" select="concat('LISTUIN/LISTUIN_ITEM/NUMUIN/NUMUIN_ITEM[',position(),']/ConosamentNum')"/>
							<xsl:with-param name="TypeDoc" select="$UinType"/>
							<xsl:with-param name="PosPkg" select="$UinPos"/>
							<xsl:with-param name="Category" select="'WARNING'"/>								
						</xsl:call-template>						
					</xsl:if>
					<xsl:if test="string-length($CnNum)>0 and string-length($UINID)>0 and  count(//CONOSAMENT_ITEM)>0 and  count(//CONOSAMENT_ITEM[normalize-space(RegNum)=$CnNum and string-length(PI_RegID)>0  and PI_RegID=$UINID])=0 and  count(//CONOSAMENT_ITEM[normalize-space(RegNum)=$CnNum and string-length(PI_RegID)>0])>0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat('Пакет содержит Реестр УИН/ПИТ в ПДС с номером Коносамента ',$CnNum,', для которого указан УИН ПИТ ',$UINID,' не соответствующий указанному в Коносаменте')"/>
							<xsl:with-param name="DocId" select="$IdUin"/>
							<xsl:with-param name="PathErr" select="concat('LISTUIN/LISTUIN_ITEM/NUMUIN/NUMUIN_ITEM[',position(),']/ConosamentNum')"/>
							<xsl:with-param name="TypeDoc" select="$UinType"/>
							<xsl:with-param name="PosPkg" select="$UinPos"/>
							<xsl:with-param name="Category" select="'WARNING'"/>								
						</xsl:call-template>						
					</xsl:if>
				</xsl:for-each>
			</xsl:for-each>	
		</xsl:template>
</xsl:stylesheet>
