<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
	<xsl:import href="../../../COMMON/FunctionForXsl.xsl"/>
	<xsl:param name="PIT_INV"/>
	<xsl:output method="xml"/>
	
	<xsl:template name="ValidContainerNum">
		<xsl:param name="Nums"/>
		<xsl:param name="notSea"/>
		<xsl:variable name="Sing0" select="string-length($Nums)&lt;18"/>
		<xsl:variable name="Sing1" select="substring($Nums,1,4)"/>
		<xsl:variable name="Sing2" select="substring($Nums,5)"/>
		<xsl:variable name="Sing11" select="translate($Sing1,'QWERTYUIOPASDFGHJKLMNBVCXZ','AAAAAAAAAAAAAAAAAAAAAAAAAA')"/>
		<xsl:variable name="Sing21">
			<xsl:choose>
				<xsl:when test="number($Sing2)!='NaN'">
					<xsl:value-of select="translate($Sing2,'0123456789', '9999999999')"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$Sing2"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="$Sing0 and $Sing11='AAAA' and $Sing21='9999999'">1</xsl:when>
			<xsl:otherwise>0</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="ErrorNode">
		<xsl:param name="MessErr"/>
		<xsl:param name="DocId"/>
		<xsl:param name="PathErr"/>
		<xsl:param name="Category"/>
		<xsl:param name="Num"/>
		<xsl:param name="TypeDoc"/>
		<xsl:param name="PosPkg"/>
		<xsl:variable name="Cat">
			<xsl:choose>
				<xsl:when test="string-length($Category)=0">ERROR</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$Category"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<RESULTINFORMATION_ITEM xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<ResultDescription><xsl:value-of select="$MessErr"/></ResultDescription>
			<ResultIdDocument><xsl:value-of select="$DocId"/></ResultIdDocument>
			<ResultTypeDocument><xsl:value-of select="$TypeDoc"/></ResultTypeDocument>
			<ResultPosInPkgDocument><xsl:value-of select="$PosPkg"/></ResultPosInPkgDocument>
			<ResultPathNode><xsl:value-of select="$PathErr"/></ResultPathNode>
			<ResultCategory><xsl:value-of select="$Cat"/></ResultCategory>
			<DocumentNumber><xsl:value-of select="$Num"/></DocumentNumber>
		</RESULTINFORMATION_ITEM>	
	</xsl:template>
	<xsl:template name="UpperCaseRus">
		<xsl:param name="string"/>
		<xsl:variable name="smallcase" select="'йцукенгшщзхъёфывапролджэячсмитьбю'"/>
		<xsl:variable name="uppercase" select="'ЙЦУКЕНГШЩЗХЪЁФЫВАПРОЛДЖЭЯЧСМИТЬБЮ'"/>
		<xsl:value-of select="translate($string, $smallcase, $uppercase)"/>
	</xsl:template>	
	<xsl:template match="/">
		<xsl:apply-templates select="node()"/>
	</xsl:template>
	<!-- проверка связанности док-тов в пакете-->
	<xsl:template match="Package">
		<ResultInformation xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<xsl:if test="count(//ESADOUT_PIT/ESADOUT_PIT_ITEM)=0">
				<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'В пакете  не хватает обязательного документа - Предварительная информация о партии товаров, перевозимых морским транспортом (ПИТ).'"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="count(//ESADOUT_PIT/ESADOUT_PIT_ITEM)>1">
				<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'Пакет содержит более одного документа - Предварительная информация о партии товаров, перевозимых морским транспортом (ПИТ). Отправка не возможна'"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:for-each select="//ESADOUT_PIT/ESADOUT_PIT_ITEM">
				<xsl:variable name="IdTd" select="../@id"/>
				<xsl:variable name="TdPos" select="position()"/>
				<xsl:variable name="TdType" select="../@ctmtd:CfgName"/>
				<xsl:variable name="TdMess" select="'Пакет содержит документ ПИТ  '"/>
				<xsl:variable name="DocForArch1" select="count(//*[string-length(@*[contains(local-name(),'CfgName')])>0 and @*[not(contains(.,'html')) and  not(contains(.,'pid'))] and not(contains(name(),'ESADOUT'))  and not(contains(name(),'DesNotif_PIResult'))])"/>
				<xsl:variable name="PITWithArch1">
					<xsl:choose>
						<xsl:when test="count(//ESADOUT_PIT)>0 and $DocForArch1>0 and count(//ESADOUT_TD)=0">1</xsl:when>
						<xsl:otherwise>0</xsl:otherwise>
					</xsl:choose>
				</xsl:variable> 
				<xsl:variable name="TypeSend">
					<xsl:choose>
						<xsl:when test="string-length($PIT_INV)>0 or $PITWithArch1=1">0</xsl:when>
						<xsl:when test="count(//child::*[contains(name(),'PIDT_') and contains(name(parent::*),'ESADOUT_PIT_ITEM') and string-length(.)>0])>0">3</xsl:when>
						<xsl:otherwise>2</xsl:otherwise>
					</xsl:choose>
				</xsl:variable> 
				<xsl:if test="$TypeSend=3">
					<xsl:variable name="TDCode" select="PIDT_DocumentCustomsCode"/>
					<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Customs_ITEM[Code=$TDCode]/Code)=0 ">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat($TdMess,' с неправильно заполненным полем Номер предварительной ДТ / ТД.Код таможенного органа  (не найден в справочнике).')"/>
							<xsl:with-param name="DocId" select="$IdTd"/>
							<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/PIDT_DocumentCustomsCode'"/>
							<xsl:with-param name="TypeDoc" select="$TdType"/>
							<xsl:with-param name="PosPkg" select="$TdPos"/>
						</xsl:call-template>
					</xsl:if>	
					<xsl:if test="string-length(PIDT_DocumentNumber)!=7 ">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat($TdMess,' с неправильно заполненным полем Номер предварительной ДТ / ТД: Порядковый номер документа по журналу регистрации - длина д.б. 7 символов .')"/>
							<xsl:with-param name="DocId" select="$IdTd"/>
							<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/PIDT_DocumentNumber'"/>
							<xsl:with-param name="TypeDoc" select="$TdType"/>
							<xsl:with-param name="PosPkg" select="$TdPos"/>
						</xsl:call-template>
					</xsl:if>	
					<xsl:if test="string-length(PIDT_DocumentDate)=0 and (string-length(PIDT_DocumentNumber)>0 or string-length(PIDT_DocumentCustomsCode)>0 or string-length(PIDT_Kind)>0)">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat($TdMess,' с не заполненным полем Дата предварительной ДТ / ТД:  .')"/>
							<xsl:with-param name="DocId" select="$IdTd"/>
							<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/PIDT_DocumentDate'"/>
							<xsl:with-param name="TypeDoc" select="$TdType"/>
							<xsl:with-param name="PosPkg" select="$TdPos"/>
						</xsl:call-template>
					</xsl:if>	
					<xsl:if test="string-length(PIDT_DocumentNumber)=0 and (string-length(PIDT_DocumentDate)>0 or string-length(PIDT_DocumentCustomsCode)>0 or string-length(PIDT_Kind)>0)">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat($TdMess,' с не заполненным полем Номер предварительной ДТ / ТД:  .')"/>
							<xsl:with-param name="DocId" select="$IdTd"/>
							<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/PIDT_DocumentNumber'"/>
							<xsl:with-param name="TypeDoc" select="$TdType"/>
							<xsl:with-param name="PosPkg" select="$TdPos"/>
						</xsl:call-template>
					</xsl:if>	
					<xsl:if test="string-length(PIDT_DocumentCustomsCode)=0 and (string-length(PIDT_DocumentDate)>0 or string-length(PIDT_DocumentNumber)>0 or string-length(PIDT_Kind)>0)">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat($TdMess,' с не заполненным полем Код таможенного органа предварительной ДТ / ТД:  .')"/>
							<xsl:with-param name="DocId" select="$IdTd"/>
							<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/PIDT_DocumentCustomsCode'"/>
							<xsl:with-param name="TypeDoc" select="$TdType"/>
							<xsl:with-param name="PosPkg" select="$TdPos"/>
						</xsl:call-template>
					</xsl:if>	
					<xsl:if test="string-length(PIDT_Kind)=0 and (string-length(PIDT_DocumentDate)>0 or string-length(PIDT_DocumentNumber)>0 or string-length(PIDT_DocumentCustomsCode)>0)">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat($TdMess,' с не заполненным полем Тип предварительной ДТ / ТД:  .')"/>
							<xsl:with-param name="DocId" select="$IdTd"/>
							<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/PIDT_Kind'"/>
							<xsl:with-param name="TypeDoc" select="$TdType"/>
							<xsl:with-param name="PosPkg" select="$TdPos"/>
						</xsl:call-template>
					</xsl:if>	
				</xsl:if>	
				<xsl:if test="$TypeSend=0">	
					<xsl:if test="string-length(Filled_PersonSurname)=0 and string-length(Filled_PersonName)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat($TdMess,' с не заполненными полями  Сведения о лице, заполнившем декларацию. Фамилия. Имя.')"/>
							<xsl:with-param name="DocId" select="$IdTd"/>
							<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/Filled_PersonSurname'"/>
							<xsl:with-param name="TypeDoc" select="$TdType"/>
							<xsl:with-param name="PosPkg" select="$TdPos"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:if>					
				<xsl:if test="$TypeSend=2">	
					<xsl:if test="string-length(Consignee_CountryCode)>0">
						<xsl:variable name="CeeCode" select="Consignee_CountryCode"/>
						<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$CeeCode]/Code)=0 ">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($TdMess,' с неправильно заполненным полем  Получатель Код cтраны(не найден в справочнике).')"/>
								<xsl:with-param name="DocId" select="$IdTd"/>
								<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/Consignee_CountryCode'"/>
								<xsl:with-param name="TypeDoc" select="$TdType"/>
								<xsl:with-param name="PosPkg" select="$TdPos"/>
							</xsl:call-template>
						</xsl:if>	
					</xsl:if>
					<xsl:if test="string-length(Consignor_CountryCode)>0">
						<xsl:variable name="CorCode" select="Consignor_CountryCode"/>
						<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$CorCode]/Code)=0 ">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($TdMess,' с неправильно заполненным полем  Отправитель Код cтраны(не найден в справочнике).')"/>
								<xsl:with-param name="DocId" select="$IdTd"/>
								<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/Consignor_CountryCode'"/>
								<xsl:with-param name="TypeDoc" select="$TdType"/>
								<xsl:with-param name="PosPkg" select="$TdPos"/>
							</xsl:call-template>
						</xsl:if>	
					</xsl:if>
					<xsl:if test="string-length(Carrier_CountryCode)>0">
						<xsl:variable name="CarCode" select="Carrier_CountryCode"/>
						<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$CarCode]/Code)=0 ">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($TdMess,' с неправильно заполненным полем  Перевозчик Код cтраны(не найден в справочнике).')"/>
								<xsl:with-param name="DocId" select="$IdTd"/>
								<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/Carrier_CountryCode'"/>
								<xsl:with-param name="TypeDoc" select="$TdType"/>
								<xsl:with-param name="PosPkg" select="$TdPos"/>
							</xsl:call-template>
						</xsl:if>	
					</xsl:if>
					
					
					<xsl:if test="string-length(Filled_PersonSurname)=0 and string-length(Filled_PersonName)>0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat($TdMess,' с не заполненным полем  Сведения о лице, заполнившем декларацию. Фамилия.')"/>
							<xsl:with-param name="DocId" select="$IdTd"/>
							<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/Filled_PersonSurname'"/>
							<xsl:with-param name="TypeDoc" select="$TdType"/>
							<xsl:with-param name="PosPkg" select="$TdPos"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="string-length(Filled_PersonSurname)>0 and string-length(Filled_PersonName)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat($TdMess,' с не заполненным полем  Сведения о лице, заполнившем декларацию. Имя.')"/>
							<xsl:with-param name="DocId" select="$IdTd"/>
							<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/Filled_PersonName'"/>
							<xsl:with-param name="TypeDoc" select="$TdType"/>
							<xsl:with-param name="PosPkg" select="$TdPos"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="string-length(ExecutionDate)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat($TdMess,' с не заполненным полем  Дата составления/представления .')"/>
							<xsl:with-param name="DocId" select="$IdTd"/>
							<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/ExecutionDate'"/>
							<xsl:with-param name="TypeDoc" select="$TdType"/>
							<xsl:with-param name="PosPkg" select="$TdPos"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="string-length(ExecutionPlace)>35">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat($TdMess,' с неправильно заполненным полем  Место составления/представления - длина поля превышает допустимое значение.')"/>
							<xsl:with-param name="DocId" select="$IdTd"/>
							<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/ExecutionPlace'"/>
							<xsl:with-param name="TypeDoc" select="$TdType"/>
							<xsl:with-param name="PosPkg" select="$TdPos"/>
						</xsl:call-template>
					</xsl:if>				
					<xsl:if test="string-length(CurrencyCode)=0 and string-length(TotalInvoiceAmount)>0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat($TdMess,' с не заполненным полем  Код валюты .')"/>
							<xsl:with-param name="DocId" select="$IdTd"/>
							<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/CurrencyCode'"/>
							<xsl:with-param name="TypeDoc" select="$TdType"/>
							<xsl:with-param name="PosPkg" select="$TdPos"/>
						</xsl:call-template>
					</xsl:if>	
					<xsl:if test="string-length(CurrencyCode)>0">
						<xsl:variable name="CuCode" select="CurrencyCode"/>
						<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Currency_ITEM[ABBR=$CuCode]/Code)=0 ">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($TdMess,' с неправильно заполненным полем Код валюты (не найден в справочнике).')"/>
								<xsl:with-param name="DocId" select="$IdTd"/>
								<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/CurrencyCode'"/>
								<xsl:with-param name="TypeDoc" select="$TdType"/>
								<xsl:with-param name="PosPkg" select="$TdPos"/>
							</xsl:call-template>
						</xsl:if>	
					</xsl:if>			
					<xsl:if test="string-length(CustomsProcedure)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat($TdMess,' с не заполненным полем Первый подраздел ТД .')"/>
							<xsl:with-param name="DocId" select="$IdTd"/>
							<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/CustomsProcedure'"/>
							<xsl:with-param name="TypeDoc" select="$TdType"/>
							<xsl:with-param name="PosPkg" select="$TdPos"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="string-length(BorderCustomsCode)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat($TdMess,' с не заполненным полем Таможенный орган Пограничный пункт пропуска .')"/>
							<xsl:with-param name="DocId" select="$IdTd"/>
							<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/BorderCustomsCode'"/>
							<xsl:with-param name="TypeDoc" select="$TdType"/>
							<xsl:with-param name="PosPkg" select="$TdPos"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="string-length(BorderCustomsCode)>0">
							<xsl:variable name="TNCode" select="BorderCustomsCode"/>
							<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Customs_ITEM[Code=$TNCode]/Code)=0 ">
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="concat($TdMess,' с неправильно заполненным полем Таможенный орган Пограничный пункт пропуска (не найден в справочнике).')"/>
									<xsl:with-param name="DocId" select="$IdTd"/>
									<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/BorderCustomsCode'"/>
									<xsl:with-param name="TypeDoc" select="$TdType"/>
									<xsl:with-param name="PosPkg" select="$TdPos"/>
								</xsl:call-template>
							</xsl:if>	
					</xsl:if>
					<xsl:if test="string-length(DispatchCountryCode)>0 and DispatchCountryCode!='00'">
						<xsl:variable name="DisCode" select="DispatchCountryCode"/>
						<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$DisCode]/Code)=0">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($TdMess,' с неправильно заполненным полем Страна отправления (Код не найден в справочнике)')"/>
								<xsl:with-param name="DocId" select="$IdTd"/>
								<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/DispatchCountryCode'"/>
								<xsl:with-param name="TypeDoc" select="$TdType"/>
								<xsl:with-param name="PosPkg" select="$TdPos"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
					<xsl:if test="string-length(DestinationCountryCode)>0 and DestinationCountryCode!='00'">
						<xsl:variable name="DesCode" select="DestinationCountryCode"/>
						<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$DesCode]/Code)=0">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($TdMess,' с неправильно заполненным полем Страна назначения (Код не найден в справочнике)')"/>
								<xsl:with-param name="DocId" select="$IdTd"/>
								<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/DestinationCountryCode'"/>
								<xsl:with-param name="TypeDoc" select="$TdType"/>
								<xsl:with-param name="PosPkg" select="$TdPos"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>	
					<xsl:if test="string-length(BorderTransport_TransportModeCode)=0 and count(BorderTransport_TransportMeans/BORDERTRANSPORT_TRANSPORTMEANS_ITEM[string-length(TMNumber)>0])>0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat($TdMess,' с не заполненным полем Код вида ТС')"/>
							<xsl:with-param name="DocId" select="$IdTd"/>
							<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/BorderTransport_TransportModeCode'"/>
							<xsl:with-param name="TypeDoc" select="$TdType"/>
							<xsl:with-param name="PosPkg" select="$TdPos"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="string-length(BorderTransport_TransportModeCode)>0">
						<xsl:variable name="ТСCode" select="BorderTransport_TransportModeCode"/>
						<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//VIDTRANS_ITEM[KOD=$ТСCode]/KOD)=0 ">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($TdMess,' с неправильно заполненным полем Код вида ТС (не найден в справочнике)')"/>
								<xsl:with-param name="DocId" select="$IdTd"/>
								<xsl:with-param name="PathErr" select="'ESADOUT_PIT/ESADOUT_PIT_ITEM/BorderTransport_TransportModeCode'"/>
								<xsl:with-param name="TypeDoc" select="$TdType"/>
								<xsl:with-param name="PosPkg" select="$TdPos"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
					<xsl:for-each select="BorderTransport_TransportMeans/BORDERTRANSPORT_TRANSPORTMEANS_ITEM">
						<xsl:variable name="PosTC" select="position()"/>
						<xsl:if test="string-length(TMNumber)=0 and string-length(NationalityCode)>0">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($TdMess,' с не заполненным полем Наименование ТС')"/>
								<xsl:with-param name="DocId" select="$IdTd"/>
								<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/BorderTransport_TransportMeans/BORDERTRANSPORT_TRANSPORTMEANS_ITEM[',$PosTC,']/TMNumber')"/>
								<xsl:with-param name="TypeDoc" select="$TdType"/>
								<xsl:with-param name="PosPkg" select="$TdPos"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="string-length(TMNumber)>0 and string-length(NationalityCode)=0">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($TdMess,' с не заполненным полем Код страны принадлежности ТС')"/>
								<xsl:with-param name="DocId" select="$IdTd"/>
								<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/BorderTransport_TransportMeans/BORDERTRANSPORT_TRANSPORTMEANS_ITEM[',$PosTC,']/NationalityCode')"/>
								<xsl:with-param name="TypeDoc" select="$TdType"/>
								<xsl:with-param name="PosPkg" select="$TdPos"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="string-length(NationalityCode)>0 and NationalityCode!='00'">
							<xsl:variable name="NatCode" select="NationalityCode"/>
							<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$NatCode]/Code)=0 ">
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="concat($TdMess,' с неправильно заполненным полем Код страны принадлежности ТС (не найден в справочнике)')"/>
									<xsl:with-param name="DocId" select="$IdTd"/>
									<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/BorderTransport_TransportMeans/BORDERTRANSPORT_TRANSPORTMEANS_ITEM[',$PosTC,']/NationalityCode')"/>
									<xsl:with-param name="TypeDoc" select="$TdType"/>
									<xsl:with-param name="PosPkg" select="$TdPos"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
					</xsl:for-each>	
				</xsl:if>	
				<xsl:if test="$TypeSend=2 or $TypeSend=0">				
					<xsl:for-each select="ESADOUT_PITGoods/ESADOUT_PITGOODS_ITEM">
						<xsl:variable name="PosGoods" select="position()"/>
						<xsl:if test="$TypeSend=2">
							<xsl:if test="string-length(GoodsNumeric)=0">
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="concat($TdMess,' с не заполненным полем Порядковый номер товара. ')"/>
									<xsl:with-param name="DocId" select="$IdTd"/>
									<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/ESADOUT_PITGoods/ESADOUT_PITGOODS_ITEM[',$PosGoods,']/GoodsNumeric')"/>
									<xsl:with-param name="TypeDoc" select="$TdType"/>
									<xsl:with-param name="PosPkg" select="$TdPos"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:if test="string-length(GoodsDescription)=0">
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="concat($TdMess,' с не заполненным полем Наименование товара. ')"/>
									<xsl:with-param name="DocId" select="$IdTd"/>
									<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/ESADOUT_PITGoods/ESADOUT_PITGOODS_ITEM[',$PosGoods,']/GoodsDescription')"/>
									<xsl:with-param name="TypeDoc" select="$TdType"/>
									<xsl:with-param name="PosPkg" select="$TdPos"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:if test="string-length(GoodsCode)>0 and string-length(GoodsCode)!=6 and string-length(GoodsCode)!=8  and string-length(GoodsCode)&lt;10">
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="concat($TdMess,' с Кодом товара по ТНВЭД, длина которого не равна 6,8 или 10 символов.')"/>
									<xsl:with-param name="DocId" select="$IdTd"/>
									<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/ESADOUT_PITGoods/ESADOUT_PITGOODS_ITEM[',$PosGoods,']/GoodsCode')"/>
									<xsl:with-param name="TypeDoc" select="$TdType"/>
									<xsl:with-param name="PosPkg" select="$TdPos"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:if test="string-length(GoodsCode)>10">
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="concat($TdMess,' с Кодом товара по ТНВЭД, длина которого более 10 символов.')"/>
									<xsl:with-param name="DocId" select="$IdTd"/>
									<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/ESADOUT_PITGoods/ESADOUT_PITGOODS_ITEM[',$PosGoods,']/GoodsCode')"/>
									<xsl:with-param name="TypeDoc" select="$TdType"/>
									<xsl:with-param name="PosPkg" select="$TdPos"/>
									<xsl:with-param name="Category" select="'WARNING'"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:if test="string-length(OriginCountryCode)>0">
								<xsl:variable name="OrCode" select="OriginCountryCode"/>
								<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$OrCode]/Code)=0">
									<xsl:call-template name="ErrorNode">
										<xsl:with-param name="MessErr" select="concat($TdMess,' с неправильно заполненным полем Код страны происхождения')"/>
										<xsl:with-param name="DocId" select="$IdTd"/>
										<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/ESADOUT_PITGoods/ESADOUT_PITGOODS_ITEM[',$PosGoods,']/OriginCountryCode')"/>
										<xsl:with-param name="TypeDoc" select="$TdType"/>
										<xsl:with-param name="PosPkg" select="$TdPos"/>
									</xsl:call-template>
								</xsl:if>
							</xsl:if>
							<xsl:if test="string-length(CodeDEI)>0">
								<xsl:variable name="MsCode" select="CodeDEI"/>
								<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//UNIT_ITEM[CODE=$MsCode]/CODE)=0">
									<xsl:call-template name="ErrorNode">
										<xsl:with-param name="MessErr" select="concat($TdMess,' с неправильно заполненным полем Код единицы измерения товара (не найден в справочнике)')"/>
										<xsl:with-param name="DocId" select="$IdTd"/>
										<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/ESADOUT_PITGoods/ESADOUT_PITGOODS_ITEM[',$PosGoods,']/CodeDEI')"/>
										<xsl:with-param name="TypeDoc" select="$TdType"/>
										<xsl:with-param name="PosPkg" select="$TdPos"/>
									</xsl:call-template>
								</xsl:if>
							</xsl:if>
							<xsl:if test="string-length(InvoicedCost)>0 and (number(InvoicedCost)=InvoicedCost) and contains(InvoicedCost,'.') and string-length(substring-after(InvoicedCost,'.'))>2">
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="concat($TdMess,' с товаром, в котором в поле Цена/ стоимость товара дробная часть более 2 зн. ')"/>
									<xsl:with-param name="DocId" select="$IdTd"/>
									<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/ESADOUT_PITGoods/ESADOUT_PITGOODS_ITEM[',$PosGoods,']/InvoicedCost')"/>
									<xsl:with-param name="Category" select="'WARNING'"/>
									<xsl:with-param name="TypeDoc" select="$TdType"/>
									<xsl:with-param name="PosPkg" select="$TdPos"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:for-each select="GoodsPackingInfo/GOODSPACKINGINFO_ITEM">
								<xsl:variable name="PosPk" select="position()"/>
								<xsl:if test="string-length(PackingQuantity)=0 and string-length(PackingCode)>0">
									<xsl:call-template name="ErrorNode">
										<xsl:with-param name="MessErr" select="concat($TdMess,' с товаром, в котором не заполено поле Количества упаковок ')"/>
										<xsl:with-param name="DocId" select="$IdTd"/>
										<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/ESADOUT_PITGoods/ESADOUT_PITGOODS_ITEM[',$PosGoods,']/GoodsPackingInfo/GOODSPACKINGINFO_ITEM[',$PosPk,']/PackingQuantity')"/>
										<xsl:with-param name="TypeDoc" select="$TdType"/>
										<xsl:with-param name="PosPkg" select="$TdPos"/>
									</xsl:call-template>
								</xsl:if>
								<xsl:if test="string-length(PackingQuantity)>0 and string-length(PackingCode)=0">
									<xsl:call-template name="ErrorNode">
										<xsl:with-param name="MessErr" select="concat($TdMess,' с товаром, в котором не заполено поле Код вида упаковки товаров ')"/>
										<xsl:with-param name="DocId" select="$IdTd"/>
										<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/ESADOUT_PITGoods/ESADOUT_PITGOODS_ITEM[',$PosGoods,']/GoodsPackingInfo/GOODSPACKINGINFO_ITEM[',$PosPk,']/PackingCode')"/>
										<xsl:with-param name="TypeDoc" select="$TdType"/>
										<xsl:with-param name="PosPkg" select="$TdPos"/>
									</xsl:call-template>
								</xsl:if>
								<xsl:if test="string-length(PackingCode)>0">
									<xsl:variable name="PkCode" select="PackingCode"/>
									<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Packing_ITEM[ID=$PkCode]/ID)=0">
										<xsl:call-template name="ErrorNode">
											<xsl:with-param name="MessErr" select="concat($TdMess,' с неправильно заполненным полем Код вида упаковки товаров (не найден в справочнике)')"/>
											<xsl:with-param name="DocId" select="$IdTd"/>
											<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/ESADOUT_PITGoods/ESADOUT_PITGOODS_ITEM[',$PosGoods,']/GoodsPackingInfo/GOODSPACKINGINFO_ITEM[',$PosPk,']/PackingCode')"/>
											<xsl:with-param name="TypeDoc" select="$TdType"/>
											<xsl:with-param name="PosPkg" select="$TdPos"/>
										</xsl:call-template>
									</xsl:if>
								</xsl:if>
							</xsl:for-each>
							<xsl:for-each select="Container/CONTAINER_ITEM[string-length(ContainerID)>0]">
							<xsl:variable name="ContNum" select="ContainerID"/>
							<xsl:variable name="VContNum">
								<xsl:call-template name="ValidContainerNum">
									<xsl:with-param name="Nums" select="$ContNum"/>
								</xsl:call-template>
							</xsl:variable>
							<xsl:if test="string-length($ContNum)>0 and $VContNum!=1">
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="concat($TdMess,' с товаром, в котором в таблице с контейнерами указан контейнер - не соответствует формату ХХХХ9999999. ')"/>
									<xsl:with-param name="DocId" select="$IdTd"/>
									<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/ESADOUT_PITGoods/ESADOUT_PITGOODS_ITEM[',$PosGoods,']/Container/CONTAINER_ITEM[',position(),']/ContainerID')"/>
									<xsl:with-param name="TypeDoc" select="$TdType"/>
									<xsl:with-param name="PosPkg" select="$TdPos"/>
									<xsl:with-param name="Category" select="'WARNING'"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:for-each>					
						</xsl:if> 
						<xsl:for-each select="EnclosedDocument/ENCLOSEDDOCUMENT_ITEM">
							<xsl:variable name="PosDoc" select="position()"/>
							<xsl:if test="string-length(ModeCode)=0 and (string-length(DocumentNumber)>0 or string-length(DocumentDate)>0 or $TypeSend=0)">
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="concat($TdMess,'  с товаром, в котором в таблице Описание прилагаемых документов не заполнено поле Вид документа. ')"/>
									<xsl:with-param name="DocId" select="$IdTd"/>
									<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/ESADOUT_PITGoods/ESADOUT_PITGOODS_ITEM[',$PosGoods,']/EnclosedDocument/ENCLOSEDDOCUMENT_ITEM[',$PosDoc,']/ModeCode')"/>
									<xsl:with-param name="TypeDoc" select="$TdType"/>
									<xsl:with-param name="PosPkg" select="$TdPos"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:if  test="$TypeSend=0">
								<xsl:if test="string-length(DocumentNumber)=0">
									<xsl:call-template name="ErrorNode">
										<xsl:with-param name="MessErr" select="concat($TdMess,'  с товаром, в котором в таблице Описание прилагаемых документов не заполнено поле Номер документа. ')"/>
										<xsl:with-param name="DocId" select="$IdTd"/>
										<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/ESADOUT_PITGoods/ESADOUT_PITGOODS_ITEM[',$PosGoods,']/EnclosedDocument/ENCLOSEDDOCUMENT_ITEM[',$PosDoc,']/DocumentNumber')"/>
										<xsl:with-param name="TypeDoc" select="$TdType"/>
										<xsl:with-param name="PosPkg" select="$TdPos"/>
									</xsl:call-template>
								</xsl:if>
								<xsl:if test="string-length(DocumentDate)=0">
									<xsl:call-template name="ErrorNode">
										<xsl:with-param name="MessErr" select="concat($TdMess,'  с товаром, в котором в таблице Описание прилагаемых документов не заполнено поле Дата документа. ')"/>
										<xsl:with-param name="DocId" select="$IdTd"/>
										<xsl:with-param name="PathErr" select="concat('ESADOUT_PIT/ESADOUT_PIT_ITEM/ESADOUT_PITGoods/ESADOUT_PITGOODS_ITEM[',$PosGoods,']/EnclosedDocument/ENCLOSEDDOCUMENT_ITEM[',$PosDoc,']/DocumentDate')"/>
										<xsl:with-param name="TypeDoc" select="$TdType"/>
										<xsl:with-param name="PosPkg" select="$TdPos"/>
									</xsl:call-template>
								</xsl:if>
							</xsl:if>
						</xsl:for-each>
					</xsl:for-each>
				</xsl:if>
			</xsl:for-each>
		</ResultInformation>
	</xsl:template>
</xsl:stylesheet>
