<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
	<xsl:output method="xml"/>
	<xsl:template name="ErrorNode">
		<xsl:param name="MessErr"/>
		<xsl:param name="DocId"/>
		<xsl:param name="PathErr"/>
		<xsl:param name="TypeDoc"/>
		<xsl:param name="PosPkg"/>
		<RESULTINFORMATION_ITEM>
			<ResultDescription><xsl:value-of select="$MessErr"/></ResultDescription>
			<ResultIdDocument><xsl:value-of select="$DocId"/></ResultIdDocument>
			<ResultTypeDocument><xsl:value-of select="$TypeDoc"/></ResultTypeDocument>
			<ResultPosInPkgDocument><xsl:value-of select="$PosPkg"/></ResultPosInPkgDocument>
			<ResultPathNode><xsl:value-of select="$PathErr"/></ResultPathNode>
		</RESULTINFORMATION_ITEM>	
	</xsl:template>
	
	<!-- проверка связанности док-тов в пакете-->
	<xsl:template match="/">
		<xsl:apply-templates select="node()"/>
	</xsl:template>

	<xsl:template match="Package">
		<xsl:variable name="MessPref">Пакет содержит  ПИ_АВИА </xsl:variable>
		<xsl:variable name="MessPref1">с не заполненным полем </xsl:variable>
		<xsl:variable name="NodePref" select="'PIT_AIR/PIT_AIR_ITEM/'"/>
		<ResultInformation xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<xsl:if test="count(PIT_AIR)=0">	
				<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr">Документ ПИТ_Авиа не заполнен. Отправка пакета не возможна.</xsl:with-param>
				</xsl:call-template>						
			</xsl:if>
			<xsl:for-each select="//PIT_AIR/PIT_AIR_ITEM">
				<xsl:variable name="IdDc" select="../@id"/> 
				<xsl:variable name="PosDoc" select="position()"/>
				<xsl:variable name="TypeDoc" select="../@ctmtd:CfgName"/>  
				<xsl:if test="string-length(AirClass)=0">	
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($MessPref,$MessPref1,'Категория воздушного судна.')"/>
						<xsl:with-param name="DocId" select="$IdDc"/>
						<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
						<xsl:with-param name="PosPkg" select="$PosDoc"/>	
						<xsl:with-param name="PathErr" select="concat($NodePref,'AirClass')"/>					
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="string-length(AirRegNumber)=0">	
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($MessPref,$MessPref1,'Регистрационный номер.')"/>
						<xsl:with-param name="DocId" select="$IdDc"/>
						<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
						<xsl:with-param name="PosPkg" select="$PosDoc"/>	
						<xsl:with-param name="PathErr" select="concat($NodePref,'AirRegNumber')"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="string-length(FlightNumber)=0">	
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($MessPref,$MessPref1,'Номер рейса.')"/>
						<xsl:with-param name="DocId" select="$IdDc"/>
						<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
						<xsl:with-param name="PosPkg" select="$PosDoc"/>	
						<xsl:with-param name="PathErr" select="concat($NodePref,'FlightNumber')"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:variable name="MessPrefCr">, в котором в разделе Перевозчик</xsl:variable>		
				<xsl:if test="string-length(AirCarrierInfo_IATACode)=0">	
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefCr,$MessPref1,'Код ИАТА')"/>
						<xsl:with-param name="DocId" select="$IdDc"/>
						<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
						<xsl:with-param name="PosPkg" select="$PosDoc"/>	
						<xsl:with-param name="PathErr" select="concat($NodePref,'AirCarrierInfo_IATACode')"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="string-length(AirCarrierInfo_RepresentativeCarrier_PersonSurname)=0 and string-length(AirCarrierInfo_RepresentativeCarrier_PersonName)>0">	
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefCr,' Представитель авиакомпании ',$MessPref1,'Фамилия')"/>
						<xsl:with-param name="DocId" select="$IdDc"/>
						<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
						<xsl:with-param name="PosPkg" select="$PosDoc"/>	
						<xsl:with-param name="PathErr" select="concat($NodePref,'AirCarrierInfo_RepresentativeCarrier_PersonSurname')"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="string-length(AirCarrierInfo_RepresentativeCarrier_PersonSurname)>0 and string-length(AirCarrierInfo_RepresentativeCarrier_PersonName)=0">	
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefCr,' Представитель авиакомпании ',$MessPref1,'Имя')"/>
						<xsl:with-param name="DocId" select="$IdDc"/>
						<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
						<xsl:with-param name="PosPkg" select="$PosDoc"/>	
						<xsl:with-param name="PathErr" select="concat($NodePref,'AirCarrierInfo_RepresentativeCarrier_PersonName')"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:variable name="MessPrefInOut">, в котором в разделе Сведения о маршруте</xsl:variable>	
				<xsl:if test="string-length(RoutingInfo_DepartureAirport_IATACode)=0">	
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefInOut,$MessPref1,'Аэропорт отправления: Код ИАТА')"/>
						<xsl:with-param name="DocId" select="$IdDc"/>
						<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
						<xsl:with-param name="PosPkg" select="$PosDoc"/>	
						<xsl:with-param name="PathErr" select="concat($NodePref,'RoutingInfo_DepartureAirport_IATACode')"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="string-length(RoutingInfo_DestinationAirport_IATACode)=0">	
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefInOut,$MessPref1,'Аэропорт назначения: Код ИАТА')"/>
						<xsl:with-param name="DocId" select="$IdDc"/>
						<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
						<xsl:with-param name="PosPkg" select="$PosDoc"/>	
						<xsl:with-param name="PathErr" select="concat($NodePref,'RoutingInfo_DestinationAirport_IATACode')"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:variable name="MessPref2">, в котором в разделе Сведения об экипаже </xsl:variable>		
				<xsl:if test="count(AirCrewInfo/AIRCREWINFO_ITEM[string-length(PersonSurname)>0 or string-length(PersonName)>0])>0">
					<xsl:for-each select="AirCrewInfo/AIRCREWINFO_ITEM[string-length(PersonSurname)>0 or string-length(PersonName)>0]">
						<xsl:if test="string-length(PersonSurname)=0">	
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($MessPref,$MessPref2,$MessPref1,' Фамилия.')"/>
								<xsl:with-param name="DocId" select="$IdDc"/>
								<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
								<xsl:with-param name="PosPkg" select="$PosDoc"/>	
								<xsl:with-param name="PathErr" select="concat($NodePref,'AirCrewInfo/AIRCREWINFO_ITEM[',position(),']/PersonSurname')"/>
							</xsl:call-template>						
						</xsl:if>
						<xsl:if test="string-length(PersonName)=0">	
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($MessPref,$MessPref2,$MessPref1,' Имя.')"/>
								<xsl:with-param name="DocId" select="$IdDc"/>
								<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
								<xsl:with-param name="PosPkg" select="$PosDoc"/>	
								<xsl:with-param name="PathErr" select="concat($NodePref,'AirCrewInfo/AIRCREWINFO_ITEM[',position(),']/PersonName')"/>
							</xsl:call-template>						
						</xsl:if>
					</xsl:for-each>
				</xsl:if>
				<xsl:variable name="MessPrefOpr">, в котором в разделе Эксплуатационные припасы </xsl:variable>		
				<xsl:if test="count(StoresInfo_Operating/STORESINFO_OPERATING_ITEM[string-length(Description)>0 or string-length(Quantity)>0])>0">
					<xsl:for-each select="StoresInfo_Operating/STORESINFO_OPERATING_ITEM[string-length(Description)>0 or string-length(Quantity)>0]">
						<xsl:if test="string-length(Description)=0">	
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefOpr,$MessPref1,' Наименование припасов.')"/>
								<xsl:with-param name="DocId" select="$IdDc"/>
								<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
								<xsl:with-param name="PosPkg" select="$PosDoc"/>	
								<xsl:with-param name="PathErr" select="concat($NodePref,'StoresInfo_Operating/STORESINFO_OPERATING_ITEM[',position(),']/Description')"/>
							</xsl:call-template>						
						</xsl:if>
						<xsl:if test="string-length(Quantity)=0">	
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefOpr,$MessPref1,' Количество припасов.')"/>
								<xsl:with-param name="DocId" select="$IdDc"/>
								<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
								<xsl:with-param name="PosPkg" select="$PosDoc"/>	
								<xsl:with-param name="PathErr" select="concat($NodePref,'StoresInfo_Operating/STORESINFO_OPERATING_ITEM[',position(),']/Quantity')"/>
							</xsl:call-template>						
						</xsl:if>
					</xsl:for-each>
				</xsl:if>
				<xsl:variable name="MessPrefSld">, в котором в разделе Продаваемые припасы </xsl:variable>		
				<xsl:if test="count(StoresInfo_Sold/STORESINFO_SOLD_ITEM[string-length(Description)>0 or string-length(Quantity)>0])>0">
					<xsl:for-each select="StoresInfo_Sold/STORESINFO_SOLD_ITEM[string-length(Description)>0 or string-length(Quantity)>0]">
						<xsl:if test="string-length(Description)=0">	
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefSld,$MessPref1,' Наименование припасов.')"/>
								<xsl:with-param name="DocId" select="$IdDc"/>
								<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
								<xsl:with-param name="PosPkg" select="$PosDoc"/>	
								<xsl:with-param name="PathErr" select="concat($NodePref,'StoresInfo_Sold/STORESINFO_SOLD_ITEM[',position(),']/Description')"/>
							</xsl:call-template>						
						</xsl:if>
						<xsl:if test="string-length(Quantity)=0">	
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefSld,$MessPref1,' Количество припасов.')"/>
								<xsl:with-param name="DocId" select="$IdDc"/>
								<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
								<xsl:with-param name="PosPkg" select="$PosDoc"/>	
								<xsl:with-param name="PathErr" select="concat($NodePref,'StoresInfo_Sold/STORESINFO_SOLD_ITEM[',position(),']/Quantity')"/>
							</xsl:call-template>						
						</xsl:if>
					</xsl:for-each>
				</xsl:if>
				<xsl:variable name="MessPrefCns">, в котором в разделе Потребительские припасы </xsl:variable>		
				<xsl:if test="count(StoresInfo_Consumer/STORESINFO_CONSUMER_ITEM[string-length(Description)>0 or string-length(Quantity)>0])>0">
					<xsl:for-each select="StoresInfo_Consumer/STORESINFO_CONSUMER_ITEM[string-length(Description)>0 or string-length(Quantity)>0]">
						<xsl:if test="string-length(Description)=0">	
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefCns,$MessPref1,' Наименование припасов.')"/>
								<xsl:with-param name="DocId" select="$IdDc"/>
								<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
								<xsl:with-param name="PosPkg" select="$PosDoc"/>	
								<xsl:with-param name="PathErr" select="concat($NodePref,'StoresInfo_Consumer/STORESINFO_CONSUMER_ITEM[',position(),']/Description')"/>
							</xsl:call-template>						
						</xsl:if>
						<xsl:if test="string-length(Quantity)=0">	
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefCns,$MessPref1,' Количество припасов.')"/>
								<xsl:with-param name="DocId" select="$IdDc"/>
								<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
								<xsl:with-param name="PosPkg" select="$PosDoc"/>	
								<xsl:with-param name="PathErr" select="concat($NodePref,'StoresInfo_Consumer/STORESINFO_CONSUMER_ITEM[',position(),']/Quantity')"/>
							</xsl:call-template>						
						</xsl:if>
					</xsl:for-each>
				</xsl:if>
				<xsl:variable name="MessPrefPrt">, в котором в разделе Сведения о перевозимых частях и оборудовании </xsl:variable>		
				<xsl:if test="count(SparePartsInfo/SPAREPARTSINFO_ITEM[string-length(Description)>0 or string-length(Quantity)>0])>0">
					<xsl:for-each select="SparePartsInfo/SPAREPARTSINFO_ITEM[string-length(Description)>0 or string-length(Quantity)>0]">
						<xsl:if test="string-length(Description)=0">	
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefPrt,$MessPref1,' Наименование припасов.')"/>
								<xsl:with-param name="DocId" select="$IdDc"/>
								<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
								<xsl:with-param name="PosPkg" select="$PosDoc"/>	
								<xsl:with-param name="PathErr" select="concat($NodePref,'SparePartsInfo/SPAREPARTSINFO_ITEM[',position(),']/Description')"/>
							</xsl:call-template>						
						</xsl:if>
						<xsl:if test="string-length(Quantity)=0">	
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefPrt,$MessPref1,' Количество припасов.')"/>
								<xsl:with-param name="DocId" select="$IdDc"/>
								<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
								<xsl:with-param name="PosPkg" select="$PosDoc"/>	
								<xsl:with-param name="PathErr" select="concat($NodePref,'SparePartsInfo/SPAREPARTSINFO_ITEM[',position(),']/Quantity')"/>
							</xsl:call-template>						
						</xsl:if>
					</xsl:for-each>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="string-length(PIDT_DocumentNumber)>0 or string-length(PIDT_DocumentCustomsCode)>0 or string-length(PIDT_DocumentDate)>0">
						<xsl:variable name="TDCode" select="PIDT_DocumentCustomsCode"/>
						<xsl:if test="string-length(document('../../../NSI/TranspNSIXml.xml')//Customs_ITEM[Code=$TDCode]/Code)=0 ">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($MessPref,' с неправильно заполненным полем Номер предварительной ДТ / ТД.Код таможенного органа  (не найден в справочнике).')"/>
								<xsl:with-param name="DocId" select="$IdDc"/>
								<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
								<xsl:with-param name="PosPkg" select="$PosDoc"/>	
								<xsl:with-param name="PathErr" select="concat($NodePref,'PIDT_DocumentCustomsCode')"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="string-length(PIDT_DocumentCustomsCode)=0 and (string-length(PIDT_DocumentNumber)>0 or string-length(PIDT_DocumentDate)>0)">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($MessPref,$MessPref1,' Номер предварительной ДТ / ТД.Код таможенного органа .')"/>
								<xsl:with-param name="DocId" select="$IdDc"/>
								<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
								<xsl:with-param name="PosPkg" select="$PosDoc"/>	
								<xsl:with-param name="PathErr" select="concat($NodePref,'PIDT_DocumentCustomsCode')"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="string-length(PIDT_DocumentNumber)=0 and (string-length(PIDT_DocumentCustomsCode)>0 or string-length(PIDT_DocumentDate)>0)">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($MessPref,$MessPref1,' Номер предварительной ДТ / ТД.Порядковый номер.')"/>
								<xsl:with-param name="DocId" select="$IdDc"/>
								<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
								<xsl:with-param name="PosPkg" select="$PosDoc"/>	
								<xsl:with-param name="PathErr" select="concat($NodePref,'PIDT_DocumentNumber')"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="string-length(PIDT_DocumentDate)=0 and (string-length(PIDT_DocumentCustomsCode)>0 or string-length(PIDT_DocumentNumber)>0)">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($MessPref,$MessPref1,' Номер предварительной ДТ / ТД.Дата документа.')"/>
								<xsl:with-param name="DocId" select="$IdDc"/>
								<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
								<xsl:with-param name="PosPkg" select="$PosDoc"/>	
								<xsl:with-param name="PathErr" select="concat($NodePref,'PIDT_DocumentDate')"/>
							</xsl:call-template>
						</xsl:if>				
						<xsl:if test="string-length(PIDT_DocumentNumber)!=7 ">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="concat($MessPref,' с неправильно заполненным полем Номер предварительной ДТ / ТД: Порядковый номер документа по журналу регистрации - длина д.б. 7 символов .')"/>
								<xsl:with-param name="DocId" select="$IdDc"/>
								<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
								<xsl:with-param name="PosPkg" select="$PosDoc"/>	
								<xsl:with-param name="PathErr" select="concat($NodePref,'PIDT_DocumentNumber')"/>
							</xsl:call-template>
						</xsl:if>	
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="MessPrefGrM">, в котором в разделе Описание товарной партии</xsl:variable>		
						<xsl:for-each select="CargoManifest/CARGOMANIFEST_ITEM">
							<xsl:variable name="CrPs" select="position()"/>
							<xsl:if test="string-length(CargoPlaceNumber)=0">	
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefGrM,$MessPref1,' Количество мест по грузовой накладной.')"/>
									<xsl:with-param name="DocId" select="$IdDc"/>
									<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
									<xsl:with-param name="PosPkg" select="$PosDoc"/>	
									<xsl:with-param name="PathErr" select="concat($NodePref,'CargoManifest/CARGOMANIFEST_ITEM[',position(),']/CargoPlaceNumber')"/>
								</xsl:call-template>						
							</xsl:if>
							<xsl:if test="string-length(BorderCustoms_Code)=0">	
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefGrM,$MessPref1,' Код таможенного органа погранчный пп.')"/>
									<xsl:with-param name="DocId" select="$IdDc"/>
									<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
									<xsl:with-param name="PosPkg" select="$PosDoc"/>	
									<xsl:with-param name="PathErr" select="concat($NodePref,'CargoManifest/CARGOMANIFEST_ITEM[',position(),']/BorderCustoms_Code')"/>
								</xsl:call-template>						
							</xsl:if>
							<xsl:if test="string-length(DocumentNumber)=0">	
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefGrM,$MessPref1,' Номер документа.')"/>
									<xsl:with-param name="DocId" select="$IdDc"/>
									<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
									<xsl:with-param name="PosPkg" select="$PosDoc"/>	
									<xsl:with-param name="PathErr" select="concat($NodePref,'CargoManifest/CARGOMANIFEST_ITEM[',position(),']/DocumentNumber')"/>
								</xsl:call-template>						
							</xsl:if>
							<xsl:if test="count(GoodsInfo/GOODSINFO_ITEM[string-length(CargoDescription)>0 and string-length(GrossWeightQuantity)>0 and string-length(NettoWeightQuantity)>0])=0">	
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefGrM,' не заполнены сведения о товарах')"/>
									<xsl:with-param name="DocId" select="$IdDc"/>
									<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
									<xsl:with-param name="PosPkg" select="$PosDoc"/>	
									<xsl:with-param name="PathErr" select="concat($NodePref,'CargoManifest/CARGOMANIFEST_ITEM[',$CrPs,']/GoodsInfo/GOODSINFO_ITEM[1]/CargoDescription')"/>
								</xsl:call-template>						
							</xsl:if>
							<xsl:for-each select="GoodsInfo/GOODSINFO_ITEM[string-length(CargoDescription)>0 or string-length(GrossWeightQuantity)>0 or string-length(NettoWeightQuantity)>0]">
								<xsl:if test="string-length(CargoDescription)=0">	
									<xsl:call-template name="ErrorNode">
										<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefGrM,$MessPref1,' Описание товара')"/>
										<xsl:with-param name="DocId" select="$IdDc"/>
										<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
										<xsl:with-param name="PosPkg" select="$PosDoc"/>	
										<xsl:with-param name="PathErr" select="concat($NodePref,'CargoManifest/CARGOMANIFEST_ITEM[',$CrPs,']/GoodsInfo/GOODSINFO_ITEM[',position(),']/CargoDescription')"/>
									</xsl:call-template>						
								</xsl:if>
								<xsl:if test="string-length(GrossWeightQuantity)=0">	
									<xsl:call-template name="ErrorNode">
										<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefGrM,$MessPref1,' Вес брутто')"/>
										<xsl:with-param name="DocId" select="$IdDc"/>
										<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
										<xsl:with-param name="PosPkg" select="$PosDoc"/>	
										<xsl:with-param name="PathErr" select="concat($NodePref,'CargoManifest/CARGOMANIFEST_ITEM[',$CrPs,']/GoodsInfo/GOODSINFO_ITEM[',position(),']/GrossWeightQuantity')"/>
									</xsl:call-template>						
								</xsl:if>
								<xsl:if test="string-length(NettoWeightQuantity)=0">	
									<xsl:call-template name="ErrorNode">
										<xsl:with-param name="MessErr" select="concat($MessPref,$MessPrefGrM,$MessPref1,' Вес нетто')"/>
										<xsl:with-param name="DocId" select="$IdDc"/>
										<xsl:with-param name="TypeDoc" select="$TypeDoc"/>
										<xsl:with-param name="PosPkg" select="$PosDoc"/>	
										<xsl:with-param name="PathErr" select="concat($NodePref,'CargoManifest/CARGOMANIFEST_ITEM[',$CrPs,']/GoodsInfo/GOODSINFO_ITEM[',position(),']/NettoWeightQuantity')"/>
									</xsl:call-template>						
								</xsl:if>
							</xsl:for-each>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>	
			</xsl:for-each>
		</ResultInformation>
	</xsl:template>
</xsl:stylesheet>
