<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
	<xsl:output method="xml"/>
	<xsl:template match="/">
		<xsl:apply-templates select="//Package"/>
	</xsl:template>
	<xsl:template match="Package">
		<ResultInformation xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<xsl:if test="not(EDTRANSIT_CARGOOP)">
				<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'В пакете отсутствует документ Сведения о грузовых операциях. Необходимо добавить и заполнить такой документ.'"/>
				</xsl:call-template>
			</xsl:if>
			<!--<xsl:if test="count(EDTRANSIT_CARGOOP) > 1">
				<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'В пакете должен быть всего один документ Сведения о грузовых операциях. Необходимо удалить лишние, оставить один.'"/>
				</xsl:call-template>
			</xsl:if>-->
			<!--TODO - проверить, что заполнены все данные для сборки таможенного документа-->
			<xsl:for-each select="//EDTRANSIT_CARGOOP[position()=last()]/EDTRANSIT_CARGOOP_ITEM">
				<xsl:variable name="Id" select="../@id"/>
				<xsl:variable name="Type" select="../@ctmtd:CfgName"/>
				<xsl:variable name="Pos" select="position()"/>
				<xsl:variable name="Mess">Пакет содержит Уведомление о необходимости проведения грузовых операций и/или продлении срока транзита</xsl:variable>
				<xsl:if test="string-length(TypeMess)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($Mess,', в котором не выбран Тип сообщения.')"/>
						<xsl:with-param name="DocId" select="$Id"/>
						<xsl:with-param name="PathErr" select="'EDTRANSIT_CARGOOP/EDTRANSIT_CARGOOP_ITEM/TypeMess'"/>
						<xsl:with-param name="TypeDoc" select="$Type"/>
						<xsl:with-param name="PosPkg" select="$Pos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(CustomsCode)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($Mess,', в котором не заполнен Код промежуточного таможенного органа.')"/>
						<xsl:with-param name="DocId" select="$Id"/>
						<xsl:with-param name="PathErr" select="'EDTRANSIT_CARGOOP/EDTRANSIT_CARGOOP_ITEM/CustomsCode'"/>
						<xsl:with-param name="TypeDoc" select="$Type"/>
						<xsl:with-param name="PosPkg" select="$Pos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(IsBodyDamaged)=0 and string-length(IsSealDamaged)>0 and number(IsSealDamaged)>-1">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($Mess,', в котором не заполнен Признак повреждения грузового отделения.')"/>
						<xsl:with-param name="DocId" select="$Id"/>
						<xsl:with-param name="PathErr" select="'EDTRANSIT_CARGOOP/EDTRANSIT_CARGOOP_ITEM/IsBodyDamaged'"/>
						<xsl:with-param name="TypeDoc" select="$Type"/>
						<xsl:with-param name="PosPkg" select="$Pos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(IsSealDamaged)=0 and string-length(IsBodyDamaged)>0 and number(IsBodyDamaged)>-1">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($Mess,', в котором не заполнен Признак повреждения пломб или требуется снятие пломб.')"/>
						<xsl:with-param name="DocId" select="$Id"/>
						<xsl:with-param name="PathErr" select="'EDTRANSIT_CARGOOP/EDTRANSIT_CARGOOP_ITEM/IsSealDamaged'"/>
						<xsl:with-param name="TypeDoc" select="$Type"/>
						<xsl:with-param name="PosPkg" select="$Pos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(IncidentDate)=0 and (string-length(Incident_CountryCode)>0 or string-length(Incident_City)>0 or string-length(Incident_StreetHouse)>0)">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($Mess,' с не заполненной графой Дата происшествия.')"/>
						<xsl:with-param name="DocId" select="$Id"/>
						<xsl:with-param name="PathErr" select="'EDTRANSIT_CARGOOP/EDTRANSIT_CARGOOP_ITEM/IncidentDate'"/>
						<xsl:with-param name="TypeDoc" select="$Type"/>
						<xsl:with-param name="PosPkg" select="$Pos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(TranshipmentKind)=0 and (string-length(ReloadPlace_CountryCode)>0 or string-length(ReloadPlace_City)>0 or string-length(ReloadPlace_StreetHouse)>0) ">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($Mess,' с не заполненной графой Вид грузовых операций.')"/>
						<xsl:with-param name="DocId" select="$Id"/>
						<xsl:with-param name="PathErr" select="'EDTRANSIT_CARGOOP/EDTRANSIT_CARGOOP_ITEM/IncidentDate'"/>
						<xsl:with-param name="TypeDoc" select="$Type"/>
						<xsl:with-param name="PosPkg" select="$Pos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:variable name="AdrNull" select="count(child::*[contains(name(),'Incident_') and string-length(.)>0])"/>
				<xsl:if test="string-length(IncidentDate)>0 and $AdrNull=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($Mess,' с не заполненным разделом Информация о происшествии - Адрес')"/>
						<xsl:with-param name="DocId" select="$Id"/>
						<xsl:with-param name="PathErr" select="'EDTRANSIT_CARGOOP/EDTRANSIT_CARGOOP_ITEM/Incident_CountryCode'"/>
						<xsl:with-param name="TypeDoc" select="$Type"/>
						<xsl:with-param name="PosPkg" select="$Pos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:variable name="RAdrNull" select="count(child::*[contains(name(),'ReloadPlace_') and string-length(.)>0])"/>
				<xsl:if test="string-length(TranshipmentKind)>0 and $RAdrNull=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($Mess,' с не заполненным разделом Место проведения грузовых и иных операций - Адрес ')"/>
						<xsl:with-param name="DocId" select="$Id"/>
						<xsl:with-param name="PathErr" select="'EDTRANSIT_CARGOOP/EDTRANSIT_CARGOOP_ITEM/ReloadPlace_CountryCode'"/>
						<xsl:with-param name="TypeDoc" select="$Type"/>
						<xsl:with-param name="PosPkg" select="$Pos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="count(Transport/TRANSPORT_ITEM)>0 and count(Transport/TRANSPORT_ITEM)!=count(Transport/TRANSPORT_ITEM[string-length(Mode)>0])">
					<xsl:for-each select="Transport/TRANSPORT_ITEM">
						<xsl:if test="string-length(Mode)=0 and count(child::*[name()!='Mode' and string-length(.)>0])>0">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит Сведения о грузовых с не заполненной графой Код вида в разделе Транспортные средства.'"/>
								<xsl:with-param name="DocId" select="$Id"/>
								<xsl:with-param name="PathErr" select="concat('EDTRANSIT_CARGOOP/EDTRANSIT_CARGOOP_ITEM/Transport/TRANSPORT_ITEM[',position,']/Mode')"/>
								<xsl:with-param name="TypeDoc" select="$Type"/>
								<xsl:with-param name="PosPkg" select="$Pos"/>
							</xsl:call-template>
						</xsl:if>	
					</xsl:for-each>
				</xsl:if>
			</xsl:for-each>
		</ResultInformation>
	</xsl:template>
	<xsl:template name="ErrorNode">
		<xsl:param name="MessErr"/>
		<xsl:param name="DocId"/>
		<xsl:param name="PathErr"/>
		<xsl:param name="Category"/>
		<xsl:param name="Num"/>
		<xsl:param name="TypeDoc"/>
		<xsl:param name="PosPkg"/>
		<xsl:variable name="Cat">
			<xsl:choose>
				<xsl:when test="string-length($Category)=0">ERROR</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$Category"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<RESULTINFORMATION_ITEM xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<ResultDescription><xsl:value-of select="$MessErr"/></ResultDescription>
			<ResultIdDocument><xsl:value-of select="$DocId"/></ResultIdDocument>
			<ResultTypeDocument><xsl:value-of select="$TypeDoc"/></ResultTypeDocument>
			<ResultPosInPkgDocument><xsl:value-of select="$PosPkg"/></ResultPosInPkgDocument>
			<ResultPathNode><xsl:value-of select="$PathErr"/></ResultPathNode>
			<ResultCategory><xsl:value-of select="$Cat"/></ResultCategory>
			<DocumentNumber><xsl:value-of select="$Num"/></DocumentNumber>
		</RESULTINFORMATION_ITEM>
	</xsl:template>
	
</xsl:stylesheet>
