<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
	<xsl:output method="xml"/>
	<xsl:template match="/">
		<xsl:apply-templates select="//Package"/>
	</xsl:template>
	<xsl:template match="Package">
		<ResultInformation xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<xsl:if test="not(EDTRANSIT_FACT_ARRIVAL)">
				<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'В пакете отсутствует документ Уведомление о фактической подаче железнодорожного состава на ЖДПП. Необходимо добавить и заполнить такой документ.'"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="count(EDTRANSIT_FACT_ARRIVAL) > 1">
				<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'В пакете должен быть всего один документ Уведомление о фактической подаче железнодорожного состава на ЖДПП. Необходимо удалить лишние, оставить один.'"/>
				</xsl:call-template>
			</xsl:if>
			<!--TODO - проверить, что в пакете доступны все данные для сборки таможенного NotifFactArrival через Package.EDTRANSIT_FACT_ARRIVAL.armti.xsl-->
						<xsl:for-each select="//EDTRANSIT_FACT_ARRIVAL/EDTRANSIT_FACT_ARRIVAL_ITEM">
				<xsl:variable name="IdEDFA" select="../@id"/>
				<xsl:variable name="EDFAPos" select="position()"/>
				<xsl:variable name="EDFAType" select="../@ctmtd:CfgName"/>
				<xsl:variable name="EDFAPath" select="'EDTRANSIT_FACT_ARRIVAL/EDTRANSIT_FACT_ARRIVAL_ITEM'"/>
				<xsl:variable name="EDFAMesN" select="'Пакет содержит Уведомление о фактической подаче железнодорожного состава на ЖДПП с не заполненным полем'"/>
				<xsl:if test="string-length(NotifDate)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($EDFAMesN,'  Дата уведомления.')"/>
						<xsl:with-param name="DocId" select="$IdEDFA"/>
						<xsl:with-param name="PathErr" select="concat($EDFAPath,'/NotifDate')"/>
						<xsl:with-param name="TypeDoc" select="$EDFAType"/>
						<xsl:with-param name="PosPkg" select="$EDFAPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(DocumentSign)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($EDFAMesN,' Признак уведомления ')"/>
						<xsl:with-param name="DocId" select="$IdEDFA"/>
						<xsl:with-param name="PathErr" select="concat($EDFAPath,'/DocumentSign')"/>
						<xsl:with-param name="TypeDoc" select="$EDFAType"/>
						<xsl:with-param name="PosPkg" select="$EDFAPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(CustomsOfficeCode)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($EDFAMesN,'  Таможенный орган убытия/прибытия: код таможенного органа ')"/>
						<xsl:with-param name="DocId" select="$IdEDFA"/>
						<xsl:with-param name="PathErr" select="concat($EDFAPath,'/CustomsOfficeCode')"/>
						<xsl:with-param name="TypeDoc" select="$EDFAType"/>
						<xsl:with-param name="PosPkg" select="$EDFAPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(CustomsOfficeCode)>0">
					<xsl:variable name="CustCode" select="CustomsOfficeCode"/>
					<xsl:variable name="CustName" select="document('../../../NSI/TranspNSIXml.xml')//Customs_ITEM[Code=$CustCode]/Name"/>
					<xsl:if test="string-length($CustName)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'В Уведомление о фактической подаче железнодорожного состава на ЖДПП  указан не существующий код таможенного поста.'"/>
							<xsl:with-param name="DocId" select="$IdEDFA"/>
							<xsl:with-param name="PathErr" select="concat($EDFAPath,'/CustomsOfficeCode')"/>
							<xsl:with-param name="TypeDoc" select="$EDFAType"/>
							<xsl:with-param name="PosPkg" select="$EDFAPos"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:if>
				<xsl:if test="string-length(DepartureStationCode)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($EDFAMesN,' Код станции отправления')"/>
						<xsl:with-param name="DocId" select="$IdEDFA"/>
						<xsl:with-param name="PathErr" select="concat($EDFAPath,'/DepartureStationCode')"/>
						<xsl:with-param name="TypeDoc" select="$EDFAType"/>
						<xsl:with-param name="PosPkg" select="$EDFAPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(DepartureStationName)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($EDFAMesN,' Наименование станции отправления')"/>
						<xsl:with-param name="DocId" select="$IdEDFA"/>
						<xsl:with-param name="PathErr" select="concat($EDFAPath,'/DepartureStationName')"/>
						<xsl:with-param name="TypeDoc" select="$EDFAType"/>
						<xsl:with-param name="PosPkg" select="$EDFAPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(DestinationStationCode)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($EDFAMesN,' Код станции назначения')"/>
						<xsl:with-param name="DocId" select="$IdEDFA"/>
						<xsl:with-param name="PathErr" select="concat($EDFAPath,'/DestinationStationCode')"/>
						<xsl:with-param name="TypeDoc" select="$EDFAType"/>
						<xsl:with-param name="PosPkg" select="$EDFAPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(DestinationStationName)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="concat($EDFAMesN,'Наименование станции назначения')"/>
						<xsl:with-param name="DocId" select="$IdEDFA"/>
						<xsl:with-param name="PathErr" select="concat($EDFAPath,'/DestinationStationName')"/>
						<xsl:with-param name="TypeDoc" select="$EDFAType"/>
						<xsl:with-param name="PosPkg" select="$EDFAPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(TD_CustomCode)>0">
					<xsl:variable name="CustCode" select="TD_CustomCode"/>
					<xsl:variable name="CustName" select="document('../../../NSI/TranspNSIXml.xml')//Customs_ITEM[Code=$CustCode]/Name"/>
					<xsl:if test="string-length($CustName)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'В Уведомление о фактической подаче железнодорожного состава на ЖДПП  указан не существующий  Код таможенного органа в номере ТД.'"/>
							<xsl:with-param name="DocId" select="$IdEDFA"/>
							<xsl:with-param name="PathErr" select="concat($EDFAPath,'/TD_CustomCode')"/>
							<xsl:with-param name="TypeDoc" select="$EDFAType"/>
							<xsl:with-param name="PosPkg" select="$EDFAPos"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:if>
			</xsl:for-each>
		</ResultInformation>
	</xsl:template>
	<xsl:template name="ErrorNode">
		<xsl:param name="MessErr"/>
		<xsl:param name="DocId"/>
		<xsl:param name="PathErr"/>
		<xsl:param name="Category"/>
		<xsl:param name="Num"/>
		<xsl:param name="TypeDoc"/>
		<xsl:param name="PosPkg"/>
		<xsl:variable name="Cat">
			<xsl:choose>
				<xsl:when test="string-length($Category)=0">ERROR</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$Category"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<RESULTINFORMATION_ITEM xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<ResultDescription>
				<xsl:value-of select="$MessErr"/>
			</ResultDescription>
			<ResultIdDocument>
				<xsl:value-of select="$DocId"/>
			</ResultIdDocument>
			<ResultTypeDocument>
				<xsl:value-of select="$TypeDoc"/>
			</ResultTypeDocument>
			<ResultPosInPkgDocument>
				<xsl:value-of select="$PosPkg"/>
			</ResultPosInPkgDocument>
			<ResultPathNode>
				<xsl:value-of select="$PathErr"/>
			</ResultPathNode>
			<ResultCategory>
				<xsl:value-of select="$Cat"/>
			</ResultCategory>
			<DocumentNumber>
				<xsl:value-of select="$Num"/>
			</DocumentNumber>
		</RESULTINFORMATION_ITEM>
	</xsl:template>
</xsl:stylesheet>
